/**
    Copyright 2017 Andrea "Stock" Stocchero

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

	    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/
package org.pepstock.charba.client.colors;

/**
 * <a href="https://github.com/ghosh/uiGradients">uiGradients</a> is a community contributed collection of beautiful multi-color
 * gradients.<br>
 * Enumerates the <a href="https://github.com/ghosh/uiGradients">uiGradients</a> items, with a set of predefined colors, in
 * order to create Charba {@link Gradient}s.
 * 
 * @author Andrea "Stock" Stocchero
 *
 */
public enum UiGradient
{
	/**
	 * UiGradient name "50 Shades of Grey" -
	 * <span style="background: linear-gradient(to right, #bdc3c7, #2c3e50); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FIFTY_SHADES_OF_GREY(UiGradientConstants.COLOR_BDC3C7, UiGradientConstants.COLOR_2C3E50),

	/**
	 * UiGradient name "80's Purple" -
	 * <span style="background: linear-gradient(to right, #41295a, #2F0743); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	EIGHTY_PURPLE(UiGradientConstants.COLOR_41295A, UiGradientConstants.COLOR_2F0743),

	/**
	 * UiGradient name "A Lost Memory" -
	 * <span style="background: linear-gradient(to right, #DE6262, #FFB88C); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	A_LOST_MEMORY(UiGradientConstants.COLOR_DE6262, UiGradientConstants.COLOR_FFB88C),

	/**
	 * UiGradient name "Abbas" -
	 * <span style="background: linear-gradient(to right, #00fff0, #0083fe); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ABBAS(UiGradientConstants.COLOR_00FFF0, UiGradientConstants.COLOR_0083FE),

	/**
	 * UiGradient name "After the Rain" -
	 * <span style="background: linear-gradient(to right, #ff75c3, #ffa647, #ffe83f, #9fff5b, #70e2ff, #cd93ff); border-style:
	 * solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AFTER_THE_RAIN(UiGradientConstants.COLOR_FF75C3, UiGradientConstants.COLOR_FFA647, UiGradientConstants.COLOR_FFE83F, UiGradientConstants.COLOR_9FFF5B, UiGradientConstants.COLOR_70E2FF, UiGradientConstants.COLOR_CD93FF),

	/**
	 * UiGradient name "Afternoon" -
	 * <span style="background: linear-gradient(to right, #000C40, #607D8B); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AFTERNOON(UiGradientConstants.COLOR_000C40, UiGradientConstants.COLOR_607D8B),

	/**
	 * UiGradient name "Ali" -
	 * <span style="background: linear-gradient(to right, #ff4b1f, #1fddff); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ALI(UiGradientConstants.COLOR_FF4B1F, UiGradientConstants.COLOR_1FDDFF),

	/**
	 * UiGradient name "Alihossein" -
	 * <span style="background: linear-gradient(to right, #f7ff00, #db36a4); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ALIHOSSEIN(UiGradientConstants.COLOR_F7FF00, UiGradientConstants.COLOR_DB36A4),

	/**
	 * UiGradient name "Alive" -
	 * <span style="background: linear-gradient(to right, #CB356B, #BD3F32); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ALIVE(UiGradientConstants.COLOR_CB356B, UiGradientConstants.COLOR_BD3F32),

	/**
	 * UiGradient name "Almost" -
	 * <span style="background: linear-gradient(to right, #ddd6f3, #faaca8); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ALMOST(UiGradientConstants.COLOR_DDD6F3, UiGradientConstants.COLOR_FAACA8),

	/**
	 * UiGradient name "Ameena" -
	 * <span style="background: linear-gradient(to right, #0c0c6d, #de512b, #98d0c1, #5bb226, #023c0d); border-style: solid;
	 * border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AMEENA(UiGradientConstants.COLOR_0C0C6D, UiGradientConstants.COLOR_DE512B, UiGradientConstants.COLOR_98D0C1, UiGradientConstants.COLOR_5BB226, UiGradientConstants.COLOR_023C0D),

	/**
	 * UiGradient name "Amethyst" -
	 * <span style="background: linear-gradient(to right, #9D50BB, #6E48AA); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AMETHYST(UiGradientConstants.COLOR_9D50BB, UiGradientConstants.COLOR_6E48AA),

	/**
	 * UiGradient name "Amin" -
	 * <span style="background: linear-gradient(to right, #8E2DE2, #4A00E0); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AMIN(UiGradientConstants.COLOR_8E2DE2, UiGradientConstants.COLOR_4A00E0),

	/**
	 * UiGradient name "Anamnisar" -
	 * <span style="background: linear-gradient(to right, #9796f0, #fbc7d4); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ANAMNISAR(UiGradientConstants.COLOR_9796F0, UiGradientConstants.COLOR_FBC7D4),

	/**
	 * UiGradient name "Andreuzza's" -
	 * <span style="background: linear-gradient(to right, #D70652, #FF025E); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ANDREUZZAS(UiGradientConstants.COLOR_D70652, UiGradientConstants.COLOR_FF025E),

	/**
	 * UiGradient name "Anwar" -
	 * <span style="background: linear-gradient(to right, #334d50, #cbcaa5); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ANWAR(UiGradientConstants.COLOR_334D50, UiGradientConstants.COLOR_CBCAA5),

	/**
	 * UiGradient name "Aqua Marine" -
	 * <span style="background: linear-gradient(to right, #1A2980, #26D0CE); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AQUA_MARINE(UiGradientConstants.COLOR_1A2980, UiGradientConstants.COLOR_26D0CE),

	/**
	 * UiGradient name "Aqualicious" -
	 * <span style="background: linear-gradient(to right, #50C9C3, #96DEDA); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AQUALICIOUS(UiGradientConstants.COLOR_50C9C3, UiGradientConstants.COLOR_96DEDA),

	/**
	 * UiGradient name "Argon" -
	 * <span style="background: linear-gradient(to right, #03001e, #7303c0, #ec38bc, #fdeff9); border-style: solid;
	 * border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ARGON(UiGradientConstants.COLOR_03001E, UiGradientConstants.COLOR_7303C0, UiGradientConstants.COLOR_EC38BC, UiGradientConstants.COLOR_FDEFF9),

	/**
	 * UiGradient name "Army" -
	 * <span style="background: linear-gradient(to right, #414d0b, #727a17); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ARMY(UiGradientConstants.COLOR_414D0B, UiGradientConstants.COLOR_727A17),

	/**
	 * UiGradient name "Ash" -
	 * <span style="background: linear-gradient(to right, #606c88, #3f4c6b); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ASH(UiGradientConstants.COLOR_606C88, UiGradientConstants.COLOR_3F4C6B),

	/**
	 * UiGradient name "Atlas" -
	 * <span style="background: linear-gradient(to right, #FEAC5E, #C779D0, #4BC0C8); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ATLAS(UiGradientConstants.COLOR_FEAC5E, UiGradientConstants.COLOR_C779D0, UiGradientConstants.COLOR_4BC0C8),

	/**
	 * UiGradient name "Aubergine" -
	 * <span style="background: linear-gradient(to right, #AA076B, #61045F); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AUBERGINE(UiGradientConstants.COLOR_AA076B, UiGradientConstants.COLOR_61045F),

	/**
	 * UiGradient name "Autumn" -
	 * <span style="background: linear-gradient(to right, #DAD299, #B0DAB9); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AUTUMN(UiGradientConstants.COLOR_DAD299, UiGradientConstants.COLOR_B0DAB9),

	/**
	 * UiGradient name "Azur Lane" -
	 * <span style="background: linear-gradient(to right, #7F7FD5, #86A8E7, #91EAE4); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AZUR_LANE(UiGradientConstants.COLOR_7F7FD5, UiGradientConstants.COLOR_86A8E7, UiGradientConstants.COLOR_91EAE4),

	/**
	 * UiGradient name "Azure Pop" -
	 * <span style="background: linear-gradient(to right, #ef32d9, #89fffd); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	AZURE_POP(UiGradientConstants.COLOR_EF32D9, UiGradientConstants.COLOR_89FFFD),

	/**
	 * UiGradient name "Back To Earth" -
	 * <span style="background: linear-gradient(to right, #00C9FF, #92FE9D); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BACK_TO_EARTH(UiGradientConstants.COLOR_00C9FF, UiGradientConstants.COLOR_92FE9D),

	/**
	 * UiGradient name "Back to the Future" -
	 * <span style="background: linear-gradient(to right, #C02425, #F0CB35); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BACK_TO_THE_FUTURE(UiGradientConstants.COLOR_C02425, UiGradientConstants.COLOR_F0CB35),

	/**
	 * UiGradient name "Behongo" -
	 * <span style="background: linear-gradient(to right, #52c234, #061700); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BEHONGO(UiGradientConstants.COLOR_52C234, UiGradientConstants.COLOR_061700),

	/**
	 * UiGradient name "Beleko" -
	 * <span style="background: linear-gradient(to right, #ff1e56, #f9c942, #1e90ff); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BELEKO(UiGradientConstants.COLOR_FF1E56, UiGradientConstants.COLOR_F9C942, UiGradientConstants.COLOR_1E90FF),

	/**
	 * UiGradient name "Between Night and Day" -
	 * <span style="background: linear-gradient(to right, #2c3e50, #3498db); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BETWEEN_NIGHT_AND_DAY(UiGradientConstants.COLOR_2C3E50, UiGradientConstants.COLOR_3498DB),

	/**
	 * UiGradient name "Between The Clouds" -
	 * <span style="background: linear-gradient(to right, #73C8A9, #373B44); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BETWEEN_THE_CLOUDS(UiGradientConstants.COLOR_73C8A9, UiGradientConstants.COLOR_373B44),

	/**
	 * UiGradient name "Bighead" -
	 * <span style="background: linear-gradient(to right, #c94b4b, #4b134f); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BIGHEAD(UiGradientConstants.COLOR_C94B4B, UiGradientConstants.COLOR_4B134F),

	/**
	 * UiGradient name "Black Rosa" -
	 * <span style="background: linear-gradient(to right, #f4c4f3, #fc67fa); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLACK_ROSA(UiGradientConstants.COLOR_F4C4F3, UiGradientConstants.COLOR_FC67FA),

	/**
	 * UiGradient name "Bleem" -
	 * <span style="background: linear-gradient(to right, #4284DB, #29EAC4); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLEEM(UiGradientConstants.COLOR_4284DB, UiGradientConstants.COLOR_29EAC4),

	/**
	 * UiGradient name "Blood Red" -
	 * <span style="background: linear-gradient(to right, #f85032, #e73827); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLOOD_RED(UiGradientConstants.COLOR_F85032, UiGradientConstants.COLOR_E73827),

	/**
	 * UiGradient name "Bloody Mary" -
	 * <span style="background: linear-gradient(to right, #FF512F, #DD2476); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLOODY_MARY(UiGradientConstants.COLOR_FF512F, UiGradientConstants.COLOR_DD2476),

	/**
	 * UiGradient name "Blooker20" -
	 * <span style="background: linear-gradient(to right, #e65c00, #F9D423); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLOOKER20(UiGradientConstants.COLOR_E65C00, UiGradientConstants.COLOR_F9D423),

	/**
	 * UiGradient name "Blooze" -
	 * <span style="background: linear-gradient(to right, #6da6be, #4b859e, #6da6be); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLOOZE(UiGradientConstants.COLOR_6DA6BE, UiGradientConstants.COLOR_4B859E, UiGradientConstants.COLOR_6DA6BE),

	/**
	 * UiGradient name "Blu" -
	 * <span style="background: linear-gradient(to right, #00416A, #E4E5E6); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLU(UiGradientConstants.COLOR_00416A, UiGradientConstants.COLOR_E4E5E6),

	/**
	 * UiGradient name "Blue and Orange" -
	 * <span style="background: linear-gradient(to right, #FD8112, #0085CA); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLUE_AND_ORANGE(UiGradientConstants.COLOR_FD8112, UiGradientConstants.COLOR_0085CA),

	/**
	 * UiGradient name "Blue Raspberry" -
	 * <span style="background: linear-gradient(to right, #00B4DB, #0083B0); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLUE_RASPBERRY(UiGradientConstants.COLOR_00B4DB, UiGradientConstants.COLOR_0083B0),

	/**
	 * UiGradient name "Blue Red" -
	 * <span style="background: linear-gradient(to right, #36B1C7, #960B33); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLUE_RED(UiGradientConstants.COLOR_36B1C7, UiGradientConstants.COLOR_960B33),

	/**
	 * UiGradient name "Blue Skies" -
	 * <span style="background: linear-gradient(to right, #56CCF2, #2F80ED); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLUE_SKIES(UiGradientConstants.COLOR_56CCF2, UiGradientConstants.COLOR_2F80ED),

	/**
	 * UiGradient name "Blue Slate" -
	 * <span style="background: linear-gradient(to right, #B5B9FF, #2B2C49); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLUE_SLATE(UiGradientConstants.COLOR_B5B9FF, UiGradientConstants.COLOR_2B2C49),

	/**
	 * UiGradient name "Bluelagoo" -
	 * <span style="background: linear-gradient(to right, #0052D4, #4364F7, #6FB1FC); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLUELAGOO(UiGradientConstants.COLOR_0052D4, UiGradientConstants.COLOR_4364F7, UiGradientConstants.COLOR_6FB1FC),

	/**
	 * UiGradient name "Blurry Beach" -
	 * <span style="background: linear-gradient(to right, #d53369, #cbad6d); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLURRY_BEACH(UiGradientConstants.COLOR_D53369, UiGradientConstants.COLOR_CBAD6D),

	/**
	 * UiGradient name "Blush" -
	 * <span style="background: linear-gradient(to right, #B24592, #F15F79); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BLUSH(UiGradientConstants.COLOR_B24592, UiGradientConstants.COLOR_F15F79),

	/**
	 * UiGradient name "Bora Bora" -
	 * <span style="background: linear-gradient(to right, #2BC0E4, #EAECC6); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BORA_BORA(UiGradientConstants.COLOR_2BC0E4, UiGradientConstants.COLOR_EAECC6),

	/**
	 * UiGradient name "Bourbon" -
	 * <span style="background: linear-gradient(to right, #EC6F66, #F3A183); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BOURBON(UiGradientConstants.COLOR_EC6F66, UiGradientConstants.COLOR_F3A183),

	/**
	 * UiGradient name "Brady Brady Fun Fun" -
	 * <span style="background: linear-gradient(to right, #00c3ff, #ffff1c); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BRADY_BRADY_FUN_FUN(UiGradientConstants.COLOR_00C3FF, UiGradientConstants.COLOR_FFFF1C),

	/**
	 * UiGradient name "Bright Vault" -
	 * <span style="background: linear-gradient(to right, #00d2ff, #928DAB); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BRIGHT_VAULT(UiGradientConstants.COLOR_00D2FF, UiGradientConstants.COLOR_928DAB),

	/**
	 * UiGradient name "Broken Hearts" -
	 * <span style="background: linear-gradient(to right, #d9a7c7, #fffcdc); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BROKEN_HEARTS(UiGradientConstants.COLOR_D9A7C7, UiGradientConstants.COLOR_FFFCDC),

	/**
	 * UiGradient name "Bupe" -
	 * <span style="background: linear-gradient(to right, #00416A, #E4E5E6); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BUPE(UiGradientConstants.COLOR_00416A, UiGradientConstants.COLOR_E4E5E6),

	/**
	 * UiGradient name "Burning Orange" -
	 * <span style="background: linear-gradient(to right, #FF416C, #FF4B2B); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BURNING_ORANGE(UiGradientConstants.COLOR_FF416C, UiGradientConstants.COLOR_FF4B2B),

	/**
	 * UiGradient name "By Design" -
	 * <span style="background: linear-gradient(to right, #009FFF, #ec2F4B); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	BY_DESIGN(UiGradientConstants.COLOR_009FFF, UiGradientConstants.COLOR_EC2F4B),

	/**
	 * UiGradient name "Calm Darya" -
	 * <span style="background: linear-gradient(to right, #5f2c82, #49a09d); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CALM_DARYA(UiGradientConstants.COLOR_5F2C82, UiGradientConstants.COLOR_49A09D),

	/**
	 * UiGradient name "Can You Feel The Love Tonight" -
	 * <span style="background: linear-gradient(to right, #4568DC, #B06AB3); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CAN_YOU_FEEL_THE_LOVE_TONIGHT(UiGradientConstants.COLOR_4568DC, UiGradientConstants.COLOR_B06AB3),

	/**
	 * UiGradient name "Candy" -
	 * <span style="background: linear-gradient(to right, #D3959B, #BFE6BA); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CANDY(UiGradientConstants.COLOR_D3959B, UiGradientConstants.COLOR_BFE6BA),

	/**
	 * UiGradient name "Celestial" -
	 * <span style="background: linear-gradient(to right, #C33764, #1D2671); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CELESTIAL(UiGradientConstants.COLOR_C33764, UiGradientConstants.COLOR_1D2671),

	/**
	 * UiGradient name "Cheer Up Emo Kid" -
	 * <span style="background: linear-gradient(to right, #556270, #FF6B6B); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CHEER_UP_EMO_KID(UiGradientConstants.COLOR_556270, UiGradientConstants.COLOR_FF6B6B),

	/**
	 * UiGradient name "Cherry" -
	 * <span style="background: linear-gradient(to right, #EB3349, #F45C43); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CHERRY(UiGradientConstants.COLOR_EB3349, UiGradientConstants.COLOR_F45C43),

	/**
	 * UiGradient name "Cherryblossoms" -
	 * <span style="background: linear-gradient(to right, #FBD3E9, #BB377D); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CHERRYBLOSSOMS(UiGradientConstants.COLOR_FBD3E9, UiGradientConstants.COLOR_BB377D),

	/**
	 * UiGradient name "Chitty Chitty Bang Bang" -
	 * <span style="background: linear-gradient(to right, #007991, #78ffd6); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CHITTY_CHITTY_BANG_BANG(UiGradientConstants.COLOR_007991, UiGradientConstants.COLOR_78FFD6),

	/**
	 * UiGradient name "Christmas" -
	 * <span style="background: linear-gradient(to right, #2F7336, #AA3A38); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CHRISTMAS(UiGradientConstants.COLOR_2F7336, UiGradientConstants.COLOR_AA3A38),

	/**
	 * UiGradient name "Cinnamint" -
	 * <span style="background: linear-gradient(to right, #4AC29A, #BDFFF3); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CINNAMINT(UiGradientConstants.COLOR_4AC29A, UiGradientConstants.COLOR_BDFFF3),

	/**
	 * UiGradient name "Citrus Peel" -
	 * <span style="background: linear-gradient(to right, #FDC830, #F37335); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CITRUS_PEEL(UiGradientConstants.COLOR_FDC830, UiGradientConstants.COLOR_F37335),

	/**
	 * UiGradient name "Clear Sky" -
	 * <span style="background: linear-gradient(to right, #005C97, #363795); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CLEAR_SKY(UiGradientConstants.COLOR_005C97, UiGradientConstants.COLOR_363795),

	/**
	 * UiGradient name "Clouds" -
	 * <span style="background: linear-gradient(to right, #ECE9E6, #FFFFFF); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CLOUDS(UiGradientConstants.COLOR_ECE9E6, UiGradientConstants.COLOR_FFFFFF),

	/**
	 * UiGradient name "Coal" -
	 * <span style="background: linear-gradient(to right, #EB5757, #000000); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COAL(UiGradientConstants.COLOR_EB5757, UiGradientConstants.COLOR_000000),

	/**
	 * UiGradient name "Cocoaa Ice" -
	 * <span style="background: linear-gradient(to right, #c0c0aa, #1cefff); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COCOAA_ICE(UiGradientConstants.COLOR_C0C0AA, UiGradientConstants.COLOR_1CEFFF),

	/**
	 * UiGradient name "Coffee Gold" -
	 * <span style="background: linear-gradient(to right, #554023, #c99846); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COFFEE_GOLD(UiGradientConstants.COLOR_554023, UiGradientConstants.COLOR_C99846),

	/**
	 * UiGradient name "Colors Of Sky" -
	 * <span style="background: linear-gradient(to right, #E0EAFC, #CFDEF3); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COLORS_OF_SKY(UiGradientConstants.COLOR_E0EAFC, UiGradientConstants.COLOR_CFDEF3),

	/**
	 * UiGradient name "Combi" -
	 * <span style="background: linear-gradient(to right, #00416A, #799F0C, #FFE000); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COMBI(UiGradientConstants.COLOR_00416A, UiGradientConstants.COLOR_799F0C, UiGradientConstants.COLOR_FFE000),

	/**
	 * UiGradient name "Compare Now" -
	 * <span style="background: linear-gradient(to right, #EF3B36, #FFFFFF); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COMPARE_NOW(UiGradientConstants.COLOR_EF3B36, UiGradientConstants.COLOR_FFFFFF),

	/**
	 * UiGradient name "Compass" -
	 * <span style="background: linear-gradient(to right, #516b8b, #056b3b); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COMPASS(UiGradientConstants.COLOR_516B8B, UiGradientConstants.COLOR_056B3B),

	/**
	 * UiGradient name "Cool Blues" -
	 * <span style="background: linear-gradient(to right, #2193b0, #6dd5ed); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COOL_BLUES(UiGradientConstants.COLOR_2193B0, UiGradientConstants.COLOR_6DD5ED),

	/**
	 * UiGradient name "Cool Brown" -
	 * <span style="background: linear-gradient(to right, #603813, #b29f94); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COOL_BROWN(UiGradientConstants.COLOR_603813, UiGradientConstants.COLOR_B29F94),

	/**
	 * UiGradient name "Cool Sky" -
	 * <span style="background: linear-gradient(to right, #2980B9, #6DD5FA, #FFFFFF); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COOL_SKY(UiGradientConstants.COLOR_2980B9, UiGradientConstants.COLOR_6DD5FA, UiGradientConstants.COLOR_FFFFFF),

	/**
	 * UiGradient name "Copper" -
	 * <span style="background: linear-gradient(to right, #B79891, #94716B); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COPPER(UiGradientConstants.COLOR_B79891, UiGradientConstants.COLOR_94716B),

	/**
	 * UiGradient name "Cosmic Fusion" -
	 * <span style="background: linear-gradient(to right, #ff00cc, #333399); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	COSMIC_FUSION(UiGradientConstants.COLOR_FF00CC, UiGradientConstants.COLOR_333399),

	/**
	 * UiGradient name "Crazy Orange I" -
	 * <span style="background: linear-gradient(to right, #D38312, #A83279); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CRAZY_ORANGE_I(UiGradientConstants.COLOR_D38312, UiGradientConstants.COLOR_A83279),

	/**
	 * UiGradient name "Crimson Tide" -
	 * <span style="background: linear-gradient(to right, #642B73, #C6426E); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CRIMSON_TIDE(UiGradientConstants.COLOR_642B73, UiGradientConstants.COLOR_C6426E),

	/**
	 * UiGradient name "Crystal Clear" -
	 * <span style="background: linear-gradient(to right, #159957, #155799); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CRYSTAL_CLEAR(UiGradientConstants.COLOR_159957, UiGradientConstants.COLOR_155799),

	/**
	 * UiGradient name "Curiosity blue" -
	 * <span style="background: linear-gradient(to right, #525252, #3d72b4); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	CURIOSITY_BLUE(UiGradientConstants.COLOR_525252, UiGradientConstants.COLOR_3D72B4),

	/**
	 * UiGradient name "DIMIGO" -
	 * <span style="background: linear-gradient(to right, #ec008c, #fc6767); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DIMIGO(UiGradientConstants.COLOR_EC008C, UiGradientConstants.COLOR_FC6767),

	/**
	 * UiGradient name "Dance To Forget" -
	 * <span style="background: linear-gradient(to right, #FF4E50, #F9D423); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DANCE_TO_FORGET(UiGradientConstants.COLOR_FF4E50, UiGradientConstants.COLOR_F9D423),

	/**
	 * UiGradient name "Dania" -
	 * <span style="background: linear-gradient(to right, #BE93C5, #7BC6CC); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DANIA(UiGradientConstants.COLOR_BE93C5, UiGradientConstants.COLOR_7BC6CC),

	/**
	 * UiGradient name "Dark Blu Two" -
	 * <span style="background: linear-gradient(to right, #004680, #4484BA); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_BLU_TWO(UiGradientConstants.COLOR_004680, UiGradientConstants.COLOR_4484BA),

	/**
	 * UiGradient name "Dark Blue Gradient" -
	 * <span style="background: linear-gradient(to right, #2774ae, #002E5D, #002E5D); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_BLUE_GRADIENT(UiGradientConstants.COLOR_2774AE, UiGradientConstants.COLOR_002E5D, UiGradientConstants.COLOR_002E5D),

	/**
	 * UiGradient name "Dark Knight" -
	 * <span style="background: linear-gradient(to right, #BA8B02, #181818); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_KNIGHT(UiGradientConstants.COLOR_BA8B02, UiGradientConstants.COLOR_181818),

	/**
	 * UiGradient name "Dark Ocean" -
	 * <span style="background: linear-gradient(to right, #373B44, #4286f4); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_OCEAN(UiGradientConstants.COLOR_373B44, UiGradientConstants.COLOR_4286F4),

	/**
	 * UiGradient name "Dark Skies" -
	 * <span style="background: linear-gradient(to right, #4B79A1, #283E51); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DARK_SKIES(UiGradientConstants.COLOR_4B79A1, UiGradientConstants.COLOR_283E51),

	/**
	 * UiGradient name "Dawn" -
	 * <span style="background: linear-gradient(to right, #F3904F, #3B4371); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DAWN(UiGradientConstants.COLOR_F3904F, UiGradientConstants.COLOR_3B4371),

	/**
	 * UiGradient name "Day Tripper" -
	 * <span style="background: linear-gradient(to right, #f857a6, #ff5858); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DAY_TRIPPER(UiGradientConstants.COLOR_F857A6, UiGradientConstants.COLOR_FF5858),

	/**
	 * UiGradient name "Decent" -
	 * <span style="background: linear-gradient(to right, #4CA1AF, #C4E0E5); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DECENT(UiGradientConstants.COLOR_4CA1AF, UiGradientConstants.COLOR_C4E0E5),

	/**
	 * UiGradient name "Deep Purple" -
	 * <span style="background: linear-gradient(to right, #673AB7, #512DA8); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DEEP_PURPLE(UiGradientConstants.COLOR_673AB7, UiGradientConstants.COLOR_512DA8),

	/**
	 * UiGradient name "Deep Sea Space" -
	 * <span style="background: linear-gradient(to right, #2C3E50, #4CA1AF); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DEEP_SEA_SPACE(UiGradientConstants.COLOR_2C3E50, UiGradientConstants.COLOR_4CA1AF),

	/**
	 * UiGradient name "Deep Space" -
	 * <span style="background: linear-gradient(to right, #000000, #434343); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DEEP_SPACE(UiGradientConstants.COLOR_000000, UiGradientConstants.COLOR_434343),

	/**
	 * UiGradient name "Delicate" -
	 * <span style="background: linear-gradient(to right, #D3CCE3, #E9E4F0); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DELICATE(UiGradientConstants.COLOR_D3CCE3, UiGradientConstants.COLOR_E9E4F0),

	/**
	 * UiGradient name "Digital Water" -
	 * <span style="background: linear-gradient(to right, #74ebd5, #ACB6E5); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DIGITAL_WATER(UiGradientConstants.COLOR_74EBD5, UiGradientConstants.COLOR_ACB6E5),

	/**
	 * UiGradient name "Dirty Fog" -
	 * <span style="background: linear-gradient(to right, #B993D6, #8CA6DB); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DIRTY_FOG(UiGradientConstants.COLOR_B993D6, UiGradientConstants.COLOR_8CA6DB),

	/**
	 * UiGradient name "Disco" -
	 * <span style="background: linear-gradient(to right, #4ECDC4, #556270); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DISCO(UiGradientConstants.COLOR_4ECDC4, UiGradientConstants.COLOR_556270),

	/**
	 * UiGradient name "Dracula" -
	 * <span style="background: linear-gradient(to right, #DC2424, #4A569D); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DRACULA(UiGradientConstants.COLOR_DC2424, UiGradientConstants.COLOR_4A569D),

	/**
	 * UiGradient name "Dull" -
	 * <span style="background: linear-gradient(to right, #C9D6FF, #E2E2E2); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DULL(UiGradientConstants.COLOR_C9D6FF, UiGradientConstants.COLOR_E2E2E2),

	/**
	 * UiGradient name "Dusk" -
	 * <span style="background: linear-gradient(to right, #2C3E50, #FD746C); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DUSK(UiGradientConstants.COLOR_2C3E50, UiGradientConstants.COLOR_FD746C),

	/**
	 * UiGradient name "Dusty Grass" -
	 * <span style="background: linear-gradient(to right, #d4fc79, #96e6a1); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	DUSTY_GRASS(UiGradientConstants.COLOR_D4FC79, UiGradientConstants.COLOR_96E6A1),

	/**
	 * UiGradient name "Earthly" -
	 * <span style="background: linear-gradient(to right, #649173, #DBD5A4); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	EARTHLY(UiGradientConstants.COLOR_649173, UiGradientConstants.COLOR_DBD5A4),

	/**
	 * UiGradient name "EasyMed" -
	 * <span style="background: linear-gradient(to right, #DCE35B, #45B649); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	EASYMED(UiGradientConstants.COLOR_DCE35B, UiGradientConstants.COLOR_45B649),

	/**
	 * UiGradient name "Ed's Sunset Gradient" -
	 * <span style="background: linear-gradient(to right, #ff7e5f, #feb47b); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	EDS_SUNSET_GRADIENT(UiGradientConstants.COLOR_FF7E5F, UiGradientConstants.COLOR_FEB47B),

	/**
	 * UiGradient name "Elate The Euge" -
	 * <span style="background: linear-gradient(to right, #8BDEDA, 43ADD0, 998EE0, E17DC2, EF9393); border-style: solid;
	 * border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ELATE_THE_EUGE(UiGradientConstants.COLOR_8BDEDA, UiGradientConstants.COLOR_43ADD0, UiGradientConstants.COLOR_998EE0, UiGradientConstants.COLOR_E17DC2, UiGradientConstants.COLOR_EF9393),

	/**
	 * UiGradient name "Electric Peacock" -
	 * <span style="background: linear-gradient(to right, #8a2be2, #0000cd, #228b22, #ccff00); border-style: solid;
	 * border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ELECTRIC_PEACOCK(UiGradientConstants.COLOR_8A2BE2, UiGradientConstants.COLOR_0000CD, UiGradientConstants.COLOR_228B22, UiGradientConstants.COLOR_CCFF00),

	/**
	 * UiGradient name "Electric Violet" -
	 * <span style="background: linear-gradient(to right, #4776E6, #8E54E9); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ELECTRIC_VIOLET(UiGradientConstants.COLOR_4776E6, UiGradientConstants.COLOR_8E54E9),

	/**
	 * UiGradient name "Emerald Sea" -
	 * <span style="background: linear-gradient(to right, #05386b, #5cdb95); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	EMERALD_SEA(UiGradientConstants.COLOR_05386B, UiGradientConstants.COLOR_5CDB95),

	/**
	 * UiGradient name "Emerald Water" -
	 * <span style="background: linear-gradient(to right, #348F50, #56B4D3); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	EMERALD_WATER(UiGradientConstants.COLOR_348F50, UiGradientConstants.COLOR_56B4D3),

	/**
	 * UiGradient name "Endless River" -
	 * <span style="background: linear-gradient(to right, #43cea2, #185a9d); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ENDLESS_RIVER(UiGradientConstants.COLOR_43CEA2, UiGradientConstants.COLOR_185A9D),

	/**
	 * UiGradient name "Evening Night" -
	 * <span style="background: linear-gradient(to right, #005AA7, #FFFDE4); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	EVENING_NIGHT(UiGradientConstants.COLOR_005AA7, UiGradientConstants.COLOR_FFFDE4),

	/**
	 * UiGradient name "Evening Sunshine" -
	 * <span style="background: linear-gradient(to right, #b92b27, #1565C0); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	EVENING_SUNSHINE(UiGradientConstants.COLOR_B92B27, UiGradientConstants.COLOR_1565C0),

	/**
	 * UiGradient name "Facebook Messenger" -
	 * <span style="background: linear-gradient(to right, #00c6ff, #0072ff); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FACEBOOK_MESSENGER(UiGradientConstants.COLOR_00C6FF, UiGradientConstants.COLOR_0072FF),

	/**
	 * UiGradient name "Farhan" -
	 * <span style="background: linear-gradient(to right, #9400D3, #4B0082); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FARHAN(UiGradientConstants.COLOR_9400D3, UiGradientConstants.COLOR_4B0082),

	/**
	 * UiGradient name "Firewatch" -
	 * <span style="background: linear-gradient(to right, #cb2d3e, #ef473a); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FIREWATCH(UiGradientConstants.COLOR_CB2D3E, UiGradientConstants.COLOR_EF473A),

	/**
	 * UiGradient name "Flame" -
	 * <span style="background: linear-gradient(to right, #ff0000, #fdcf58); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FLAME(UiGradientConstants.COLOR_FF0000, UiGradientConstants.COLOR_FDCF58),

	/**
	 * UiGradient name "Flare" -
	 * <span style="background: linear-gradient(to right, #f12711, #f5af19); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FLARE(UiGradientConstants.COLOR_F12711, UiGradientConstants.COLOR_F5AF19),

	/**
	 * UiGradient name "Flickr" -
	 * <span style="background: linear-gradient(to right, #ff0084, #33001b); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FLICKR(UiGradientConstants.COLOR_FF0084, UiGradientConstants.COLOR_33001B),

	/**
	 * UiGradient name "Flower" -
	 * <span style="background: linear-gradient(to right, #DCFFBD, #CC86D1); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FLOWER(UiGradientConstants.COLOR_DCFFBD, UiGradientConstants.COLOR_CC86D1),

	/**
	 * UiGradient name "Forest" -
	 * <span style="background: linear-gradient(to right, #5A3F37, #2C7744); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FOREST(UiGradientConstants.COLOR_5A3F37, UiGradientConstants.COLOR_2C7744),

	/**
	 * UiGradient name "Forever Lost" -
	 * <span style="background: linear-gradient(to right, #5D4157, #A8CABA); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FOREVER_LOST(UiGradientConstants.COLOR_5D4157, UiGradientConstants.COLOR_A8CABA),

	/**
	 * UiGradient name "Fresh Turboscent" -
	 * <span style="background: linear-gradient(to right, #F1F2B5, #135058); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FRESH_TURBOSCENT(UiGradientConstants.COLOR_F1F2B5, UiGradientConstants.COLOR_135058),

	/**
	 * UiGradient name "Friday" -
	 * <span style="background: linear-gradient(to right, #83a4d4, #b6fbff); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FRIDAY(UiGradientConstants.COLOR_83A4D4, UiGradientConstants.COLOR_B6FBFF),

	/**
	 * UiGradient name "From Ice To Fire" -
	 * <span style="background: linear-gradient(to right, #72C6EF, #004E8F); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FROM_ICE_TO_FIRE(UiGradientConstants.COLOR_72C6EF, UiGradientConstants.COLOR_004E8F),

	/**
	 * UiGradient name "Frost" -
	 * <span style="background: linear-gradient(to right, #000428, #004e92); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FROST(UiGradientConstants.COLOR_000428, UiGradientConstants.COLOR_004E92),

	/**
	 * UiGradient name "Frozen" -
	 * <span style="background: linear-gradient(to right, #403B4A, #E7E9BB); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	FROZEN(UiGradientConstants.COLOR_403B4A, UiGradientConstants.COLOR_E7E9BB),

	/**
	 * UiGradient name "Grade Grey" -
	 * <span style="background: linear-gradient(to right, #bdc3c7, #2c3e50); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GRADE_GREY(UiGradientConstants.COLOR_BDC3C7, UiGradientConstants.COLOR_2C3E50),

	/**
	 * UiGradient name "Grapefruit Sunset" -
	 * <span style="background: linear-gradient(to right, #e96443, #904e95); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GRAPEFRUIT_SUNSET(UiGradientConstants.COLOR_E96443, UiGradientConstants.COLOR_904E95),

	/**
	 * UiGradient name "Green Beach" -
	 * <span style="background: linear-gradient(to right, #02AAB0, #00CDAC); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GREEN_BEACH(UiGradientConstants.COLOR_02AAB0, UiGradientConstants.COLOR_00CDAC),

	/**
	 * UiGradient name "Green and Blue" -
	 * <span style="background: linear-gradient(to right, #c2e59c, #64b3f4); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GREEN_AND_BLUE(UiGradientConstants.COLOR_C2E59C, UiGradientConstants.COLOR_64B3F4),

	/**
	 * UiGradient name "Green to dark" -
	 * <span style="background: linear-gradient(to right, #6A9113, #141517); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	GREEN_TO_DARK(UiGradientConstants.COLOR_6A9113, UiGradientConstants.COLOR_141517),

	/**
	 * UiGradient name "Haikus" -
	 * <span style="background: linear-gradient(to right, #fd746c, #ff9068); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	HAIKUS(UiGradientConstants.COLOR_FD746C, UiGradientConstants.COLOR_FF9068),

	/**
	 * UiGradient name "Harmonic Energy" -
	 * <span style="background: linear-gradient(to right, #16A085, #F4D03F); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	HARMONIC_ENERGY(UiGradientConstants.COLOR_16A085, UiGradientConstants.COLOR_F4D03F),

	/**
	 * UiGradient name "Harvey" -
	 * <span style="background: linear-gradient(to right, #1f4037, #99f2c8); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	HARVEY(UiGradientConstants.COLOR_1F4037, UiGradientConstants.COLOR_99F2C8),

	/**
	 * UiGradient name "Hazel" -
	 * <span style="background: linear-gradient(to right, #77A1D3, #79CBCA, #E684AE); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	HAZEL(UiGradientConstants.COLOR_77A1D3, UiGradientConstants.COLOR_79CBCA, UiGradientConstants.COLOR_E684AE),

	/**
	 * UiGradient name "Hersheys" -
	 * <span style="background: linear-gradient(to right, #1e130c, #9a8478); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	HERSHEYS(UiGradientConstants.COLOR_1E130C, UiGradientConstants.COLOR_9A8478),

	/**
	 * UiGradient name "Honey Dew" -
	 * <span style="background: linear-gradient(to right, #43C6AC, #F8FFAE); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	HONEY_DEW(UiGradientConstants.COLOR_43C6AC, UiGradientConstants.COLOR_F8FFAE),

	/**
	 * UiGradient name "Horizon" -
	 * <span style="background: linear-gradient(to right, #003973, #E5E5BE); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	HORIZON(UiGradientConstants.COLOR_003973, UiGradientConstants.COLOR_E5E5BE),

	/**
	 * UiGradient name "Html" -
	 * <span style="background: linear-gradient(to right, #E44D26, #F16529); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	HTML(UiGradientConstants.COLOR_E44D26, UiGradientConstants.COLOR_F16529),

	/**
	 * UiGradient name "Hydrogen" -
	 * <span style="background: linear-gradient(to right, #667db6, #0082c8, #0082c8, #667db6); border-style: solid;
	 * border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	HYDROGEN(UiGradientConstants.COLOR_667DB6, UiGradientConstants.COLOR_0082C8, UiGradientConstants.COLOR_0082C8, UiGradientConstants.COLOR_667DB6),

	/**
	 * UiGradient name "Hyper Blue" -
	 * <span style="background: linear-gradient(to right, #59CDE9, #0A2A88); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	HYPER_BLUE(UiGradientConstants.COLOR_59CDE9, UiGradientConstants.COLOR_0A2A88),

	/**
	 * UiGradient name "IIIT Delhi" -
	 * <span style="background: linear-gradient(to right, #808080, #3fada8); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	IIIT_DELHI(UiGradientConstants.COLOR_808080, UiGradientConstants.COLOR_3FADA8),

	/**
	 * UiGradient name "Ibiza Sunset" -
	 * <span style="background: linear-gradient(to right, #ee0979, #ff6a00); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	IBIZA_SUNSET(UiGradientConstants.COLOR_EE0979, UiGradientConstants.COLOR_FF6A00),

	/**
	 * UiGradient name "Ibtesam" -
	 * <span style="background: linear-gradient(to right, #00F5A0, #00D9F5); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	IBTESAM(UiGradientConstants.COLOR_00F5A0, UiGradientConstants.COLOR_00D9F5),

	/**
	 * UiGradient name "Inbox" -
	 * <span style="background: linear-gradient(to right, #457fca, #5691c8); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	INBOX(UiGradientConstants.COLOR_457FCA, UiGradientConstants.COLOR_5691C8),

	/**
	 * UiGradient name "Influenza" -
	 * <span style="background: linear-gradient(to right, #C04848, #480048); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	INFLUENZA(UiGradientConstants.COLOR_C04848, UiGradientConstants.COLOR_480048),

	/**
	 * UiGradient name "Instagram" -
	 * <span style="background: linear-gradient(to right, #833ab4, #fd1d1d, #fcb045); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	INSTAGRAM(UiGradientConstants.COLOR_833AB4, UiGradientConstants.COLOR_FD1D1D, UiGradientConstants.COLOR_FCB045),

	/**
	 * UiGradient name "Intuitive Purple" -
	 * <span style="background: linear-gradient(to right, #DA22FF, #9733EE); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	INTUITIVE_PURPLE(UiGradientConstants.COLOR_DA22FF, UiGradientConstants.COLOR_9733EE),

	/**
	 * UiGradient name "JShine" -
	 * <span style="background: linear-gradient(to right, #12c2e9, #c471ed, #f64f59); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	JSHINE(UiGradientConstants.COLOR_12C2E9, UiGradientConstants.COLOR_C471ED, UiGradientConstants.COLOR_F64F59),

	/**
	 * UiGradient name "Jaipur" -
	 * <span style="background: linear-gradient(to right, #DBE6F6, #C5796D); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	JAIPUR(UiGradientConstants.COLOR_DBE6F6, UiGradientConstants.COLOR_C5796D),

	/**
	 * UiGradient name "Jodhpur" -
	 * <span style="background: linear-gradient(to right, #9CECFB, #65C7F7, #0052D4); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	JODHPUR(UiGradientConstants.COLOR_9CECFB, UiGradientConstants.COLOR_65C7F7, UiGradientConstants.COLOR_0052D4),

	/**
	 * UiGradient name "Jonquil" -
	 * <span style="background: linear-gradient(to right, #FFEEEE, #DDEFBB); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	JONQUIL(UiGradientConstants.COLOR_FFEEEE, UiGradientConstants.COLOR_DDEFBB),

	/**
	 * UiGradient name "Joomla" -
	 * <span style="background: linear-gradient(to right, #1e3c72, #2a5298); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	JOOMLA(UiGradientConstants.COLOR_1E3C72, UiGradientConstants.COLOR_2A5298),

	/**
	 * UiGradient name "Juicy Orange" -
	 * <span style="background: linear-gradient(to right, #FF8008, #FFC837); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	JUICY_ORANGE(UiGradientConstants.COLOR_FF8008, UiGradientConstants.COLOR_FFC837),

	/**
	 * UiGradient name "Jupiter" -
	 * <span style="background: linear-gradient(to right, #ffd89b, #19547b); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	JUPITER(UiGradientConstants.COLOR_FFD89B, UiGradientConstants.COLOR_19547B),

	/**
	 * UiGradient name "Kashmir" -
	 * <span style="background: linear-gradient(to right, #614385, #516395); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	KASHMIR(UiGradientConstants.COLOR_614385, UiGradientConstants.COLOR_516395),

	/**
	 * UiGradient name "Kimoby Is The New Blue" -
	 * <span style="background: linear-gradient(to right, #396afc, #2948ff); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	KIMOBY_IS_THE_NEW_BLUE(UiGradientConstants.COLOR_396AFC, UiGradientConstants.COLOR_2948FF),

	/**
	 * UiGradient name "King Yna" -
	 * <span style="background: linear-gradient(to right, #1a2a6c, #b21f1f, #fdbb2d); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	KING_YNA(UiGradientConstants.COLOR_1A2A6C, UiGradientConstants.COLOR_B21F1F, UiGradientConstants.COLOR_FDBB2D),

	/**
	 * UiGradient name "Koko Caramel" -
	 * <span style="background: linear-gradient(to right, #D1913C, #FFD194); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	KOKO_CARAMEL(UiGradientConstants.COLOR_D1913C, UiGradientConstants.COLOR_FFD194),

	/**
	 * UiGradient name "Kye Meh" -
	 * <span style="background: linear-gradient(to right, #8360c3, #2ebf91); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	KYE_MEH(UiGradientConstants.COLOR_8360C3, UiGradientConstants.COLOR_2EBF91),

	/**
	 * UiGradient name "Kyoo Pal" -
	 * <span style="background: linear-gradient(to right, #dd3e54, #6be585); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	KYOO_PAL(UiGradientConstants.COLOR_DD3E54, UiGradientConstants.COLOR_6BE585),

	/**
	 * UiGradient name "Kyoo Tah" -
	 * <span style="background: linear-gradient(to right, #544a7d, #ffd452); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	KYOO_TAH(UiGradientConstants.COLOR_544A7D, UiGradientConstants.COLOR_FFD452),

	/**
	 * UiGradient name "Kyoto" -
	 * <span style="background: linear-gradient(to right, #c21500, #ffc500); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	KYOTO(UiGradientConstants.COLOR_C21500, UiGradientConstants.COLOR_FFC500),

	/**
	 * UiGradient name "Lawrencium" -
	 * <span style="background: linear-gradient(to right, #0f0c29, #302b63, #24243e); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LAWRENCIUM(UiGradientConstants.COLOR_0F0C29, UiGradientConstants.COLOR_302B63, UiGradientConstants.COLOR_24243E),

	/**
	 * UiGradient name "Learning and Leading" -
	 * <span style="background: linear-gradient(to right, #F7971E, #FFD200); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LEARNING_AND_LEADING(UiGradientConstants.COLOR_F7971E, UiGradientConstants.COLOR_FFD200),

	/**
	 * UiGradient name "Lemon Lime" -
	 * <span style="background: linear-gradient(to right, #7ec6bc, #ebe717); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LEMON_LIME(UiGradientConstants.COLOR_7EC6BC, UiGradientConstants.COLOR_EBE717),

	/**
	 * UiGradient name "Lemon Twist" -
	 * <span style="background: linear-gradient(to right, #3CA55C, #B5AC49); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LEMON_TWIST(UiGradientConstants.COLOR_3CA55C, UiGradientConstants.COLOR_B5AC49),

	/**
	 * UiGradient name "Lensod" -
	 * <span style="background: linear-gradient(to right, #6025F5, #FF5555); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LENSOD(UiGradientConstants.COLOR_6025F5, UiGradientConstants.COLOR_FF5555),

	/**
	 * UiGradient name "Light Orange" -
	 * <span style="background: linear-gradient(to right, #FFB75E, #ED8F03); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIGHT_ORANGE(UiGradientConstants.COLOR_FFB75E, UiGradientConstants.COLOR_ED8F03),

	/**
	 * UiGradient name "Limeade" -
	 * <span style="background: linear-gradient(to right, #A1FFCE, #FAFFD1); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIMEADE(UiGradientConstants.COLOR_A1FFCE, UiGradientConstants.COLOR_FAFFD1),

	/**
	 * UiGradient name "Lithium" -
	 * <span style="background: linear-gradient(to right, #6D6027, #D3CBB8); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LITHIUM(UiGradientConstants.COLOR_6D6027, UiGradientConstants.COLOR_D3CBB8),

	/**
	 * UiGradient name "Little Leaf" -
	 * <span style="background: linear-gradient(to right, #76b852, #8DC26F); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LITTLE_LEAF(UiGradientConstants.COLOR_76B852, UiGradientConstants.COLOR_8DC26F),

	/**
	 * UiGradient name "Lizard" -
	 * <span style="background: linear-gradient(to right, #304352, #d7d2cc); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LIZARD(UiGradientConstants.COLOR_304352, UiGradientConstants.COLOR_D7D2CC),

	/**
	 * UiGradient name "Love Couple" -
	 * <span style="background: linear-gradient(to right, #3a6186, #89253e); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LOVE_COUPLE(UiGradientConstants.COLOR_3A6186, UiGradientConstants.COLOR_89253E),

	/**
	 * UiGradient name "Love and Liberty" -
	 * <span style="background: linear-gradient(to right, #200122, #6f0000); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LOVE_AND_LIBERTY(UiGradientConstants.COLOR_200122, UiGradientConstants.COLOR_6F0000),

	/**
	 * UiGradient name "Lunada" -
	 * <span style="background: linear-gradient(to right, #5433FF, #20BDFF, #A5FECB); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LUNADA(UiGradientConstants.COLOR_5433FF, UiGradientConstants.COLOR_20BDFF, UiGradientConstants.COLOR_A5FECB),

	/**
	 * UiGradient name "Lush" -
	 * <span style="background: linear-gradient(to right, #56ab2f, #a8e063); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	LUSH(UiGradientConstants.COLOR_56AB2F, UiGradientConstants.COLOR_A8E063),

	/**
	 * UiGradient name "Magic" -
	 * <span style="background: linear-gradient(to right, #59C173, #a17fe0, #5D26C1); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MAGIC(UiGradientConstants.COLOR_59C173, UiGradientConstants.COLOR_A17FE0, UiGradientConstants.COLOR_5D26C1),

	/**
	 * UiGradient name "Maldives" -
	 * <span style="background: linear-gradient(to right, #B2FEFA, #0ED2F7); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MALDIVES(UiGradientConstants.COLOR_B2FEFA, UiGradientConstants.COLOR_0ED2F7),

	/**
	 * UiGradient name "Man of Steel" -
	 * <span style="background: linear-gradient(to right, #780206, #061161); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MAN_OF_STEEL(UiGradientConstants.COLOR_780206, UiGradientConstants.COLOR_061161),

	/**
	 * UiGradient name "Mango" -
	 * <span style="background: linear-gradient(to right, #ffe259, #ffa751); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MANGO(UiGradientConstants.COLOR_FFE259, UiGradientConstants.COLOR_FFA751),

	/**
	 * UiGradient name "Mango Papaya" -
	 * <span style="background: linear-gradient(to right, #de8a41, #2ada53); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MANGO_PAPAYA(UiGradientConstants.COLOR_DE8A41, UiGradientConstants.COLOR_2ADA53),

	/**
	 * UiGradient name "Mango Pulp" -
	 * <span style="background: linear-gradient(to right, #F09819, #EDDE5D); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MANGO_PULP(UiGradientConstants.COLOR_F09819, UiGradientConstants.COLOR_EDDE5D),

	/**
	 * UiGradient name "Mantle" -
	 * <span style="background: linear-gradient(to right, #24C6DC, #514A9D); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MANTLE(UiGradientConstants.COLOR_24C6DC, UiGradientConstants.COLOR_514A9D),

	/**
	 * UiGradient name "Margo" -
	 * <span style="background: linear-gradient(to right, #FFEFBA, #FFFFFF); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MARGO(UiGradientConstants.COLOR_FFEFBA, UiGradientConstants.COLOR_FFFFFF),

	/**
	 * UiGradient name "Martini" -
	 * <span style="background: linear-gradient(to right, #FDFC47, #24FE41); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MARTINI(UiGradientConstants.COLOR_FDFC47, UiGradientConstants.COLOR_24FE41),

	/**
	 * UiGradient name "Master Card" -
	 * <span style="background: linear-gradient(to right, #f46b45, #eea849); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MASTER_CARD(UiGradientConstants.COLOR_F46B45, UiGradientConstants.COLOR_EEA849),

	/**
	 * UiGradient name "Mauve" -
	 * <span style="background: linear-gradient(to right, #42275a, #734b6d); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MAUVE(UiGradientConstants.COLOR_42275A, UiGradientConstants.COLOR_734B6D),

	/**
	 * UiGradient name "MegaTron" -
	 * <span style="background: linear-gradient(to right, #C6FFDD, #FBD786, #f7797d); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MEGATRON(UiGradientConstants.COLOR_C6FFDD, UiGradientConstants.COLOR_FBD786, UiGradientConstants.COLOR_F7797D),

	/**
	 * UiGradient name "Mello" -
	 * <span style="background: linear-gradient(to right, #c0392b, #8e44ad); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MELLO(UiGradientConstants.COLOR_C0392B, UiGradientConstants.COLOR_8E44AD),

	/**
	 * UiGradient name "Memariani" -
	 * <span style="background: linear-gradient(to right, #aa4b6b, #6b6b83, #3b8d99); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MEMARIANI(UiGradientConstants.COLOR_AA4B6B, UiGradientConstants.COLOR_6B6B83, UiGradientConstants.COLOR_3B8D99),

	/**
	 * UiGradient name "Meridian" -
	 * <span style="background: linear-gradient(to right, #283c86, #45a247); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MERIDIAN(UiGradientConstants.COLOR_283C86, UiGradientConstants.COLOR_45A247),

	/**
	 * UiGradient name "Metallic Toad" -
	 * <span style="background: linear-gradient(to right, #abbaab, #ffffff); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	METALLIC_TOAD(UiGradientConstants.COLOR_ABBAAB, UiGradientConstants.COLOR_FFFFFF),

	/**
	 * UiGradient name "Metapolis" -
	 * <span style="background: linear-gradient(to right, #659999, #f4791f); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	METAPOLIS(UiGradientConstants.COLOR_659999, UiGradientConstants.COLOR_F4791F),

	/**
	 * UiGradient name "Miaka" -
	 * <span style="background: linear-gradient(to right, #FC354C, #0ABFBC); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MIAKA(UiGradientConstants.COLOR_FC354C, UiGradientConstants.COLOR_0ABFBC),

	/**
	 * UiGradient name "Miami Dolphins" -
	 * <span style="background: linear-gradient(to right, #4DA0B0, #D39D38); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MIAMI_DOLPHINS(UiGradientConstants.COLOR_4DA0B0, UiGradientConstants.COLOR_D39D38),

	/**
	 * UiGradient name "Midnight City" -
	 * <span style="background: linear-gradient(to right, #232526, #414345); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MIDNIGHT_CITY(UiGradientConstants.COLOR_232526, UiGradientConstants.COLOR_414345),

	/**
	 * UiGradient name "Mild" -
	 * <span style="background: linear-gradient(to right, #67B26F, #4ca2cd); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MILD(UiGradientConstants.COLOR_67B26F, UiGradientConstants.COLOR_4CA2CD),

	/**
	 * UiGradient name "Mini" -
	 * <span style="background: linear-gradient(to right, #30E8BF, #FF8235); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MINI(UiGradientConstants.COLOR_30E8BF, UiGradientConstants.COLOR_FF8235),

	/**
	 * UiGradient name "Minimal Red" -
	 * <span style="background: linear-gradient(to right, #F00000, #DC281E); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MINIMAL_RED(UiGradientConstants.COLOR_F00000, UiGradientConstants.COLOR_DC281E),

	/**
	 * UiGradient name "Minnesota Vikings" -
	 * <span style="background: linear-gradient(to right, #5614B0, #DBD65C); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MINNESOTA_VIKINGS(UiGradientConstants.COLOR_5614B0, UiGradientConstants.COLOR_DBD65C),

	/**
	 * UiGradient name "Mirage" -
	 * <span style="background: linear-gradient(to right, #16222A, #3A6073); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MIRAGE(UiGradientConstants.COLOR_16222A, UiGradientConstants.COLOR_3A6073),

	/**
	 * UiGradient name "Misty Meadow" -
	 * <span style="background: linear-gradient(to right, #215f00, #e4e4d9); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MISTY_MEADOW(UiGradientConstants.COLOR_215F00, UiGradientConstants.COLOR_E4E4D9),

	/**
	 * UiGradient name "Mojito" -
	 * <span style="background: linear-gradient(to right, #1D976C, #93F9B9); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MOJITO(UiGradientConstants.COLOR_1D976C, UiGradientConstants.COLOR_93F9B9),

	/**
	 * UiGradient name "Monte Carlo" -
	 * <span style="background: linear-gradient(to right, #CC95C0, #DBD4B4, #7AA1D2); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MONTE_CARLO(UiGradientConstants.COLOR_CC95C0, UiGradientConstants.COLOR_DBD4B4, UiGradientConstants.COLOR_7AA1D2),

	/**
	 * UiGradient name "Moon Purple" -
	 * <span style="background: linear-gradient(to right, #4e54c8, #8f94fb); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MOON_PURPLE(UiGradientConstants.COLOR_4E54C8, UiGradientConstants.COLOR_8F94FB),

	/**
	 * UiGradient name "Moonlit Asteroid" -
	 * <span style="background: linear-gradient(to right, #0F2027, #203A43, #2C5364); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MOONLIT_ASTEROID(UiGradientConstants.COLOR_0F2027, UiGradientConstants.COLOR_203A43, UiGradientConstants.COLOR_2C5364),

	/**
	 * UiGradient name "Moonrise" -
	 * <span style="background: linear-gradient(to right, #DAE2F8, #D6A4A4); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MOONRISE(UiGradientConstants.COLOR_DAE2F8, UiGradientConstants.COLOR_D6A4A4),

	/**
	 * UiGradient name "Moonwalker" -
	 * <span style="background: linear-gradient(to right, #152331, #000000); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MOONWALKER(UiGradientConstants.COLOR_152331, UiGradientConstants.COLOR_000000),

	/**
	 * UiGradient name "Moor" -
	 * <span style="background: linear-gradient(to right, #616161, #9bc5c3); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MOOR(UiGradientConstants.COLOR_616161, UiGradientConstants.COLOR_9BC5C3),

	/**
	 * UiGradient name "Moss" -
	 * <span style="background: linear-gradient(to right, #134E5E, #71B280); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MOSS(UiGradientConstants.COLOR_134E5E, UiGradientConstants.COLOR_71B280),

	/**
	 * UiGradient name "Mystic" -
	 * <span style="background: linear-gradient(to right, #757F9A, #D7DDE8); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	MYSTIC(UiGradientConstants.COLOR_757F9A, UiGradientConstants.COLOR_D7DDE8),

	/**
	 * UiGradient name "Namn" -
	 * <span style="background: linear-gradient(to right, #a73737, #7a2828); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	NAMN(UiGradientConstants.COLOR_A73737, UiGradientConstants.COLOR_7A2828),

	/**
	 * UiGradient name "Nelson" -
	 * <span style="background: linear-gradient(to right, #f2709c, #ff9472); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	NELSON(UiGradientConstants.COLOR_F2709C, UiGradientConstants.COLOR_FF9472),

	/**
	 * UiGradient name "Neon Green" -
	 * <span style="background: linear-gradient(to right, #81ff8a, #64965e); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	NEON_GREEN(UiGradientConstants.COLOR_81FF8A, UiGradientConstants.COLOR_64965E),

	/**
	 * UiGradient name "Neon Life" -
	 * <span style="background: linear-gradient(to right, #B3FFAB, #12FFF7); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	NEON_LIFE(UiGradientConstants.COLOR_B3FFAB, UiGradientConstants.COLOR_12FFF7),

	/**
	 * UiGradient name "Nepal" -
	 * <span style="background: linear-gradient(to right, #de6161, #2657eb); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	NEPAL(UiGradientConstants.COLOR_DE6161, UiGradientConstants.COLOR_2657EB),

	/**
	 * UiGradient name "Netflix" -
	 * <span style="background: linear-gradient(to right, #8E0E00, #1F1C18); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	NETFLIX(UiGradientConstants.COLOR_8E0E00, UiGradientConstants.COLOR_1F1C18),

	/**
	 * UiGradient name "Neuromancer" -
	 * <span style="background: linear-gradient(to right, #f953c6, #b91d73); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	NEUROMANCER(UiGradientConstants.COLOR_F953C6, UiGradientConstants.COLOR_B91D73),

	/**
	 * UiGradient name "Newspaper" -
	 * <span style="background: linear-gradient(to right, #8a2be2, #ffa500, #f8f8ff); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	NEWSPAPER(UiGradientConstants.COLOR_8A2BE2, UiGradientConstants.COLOR_FFA500, UiGradientConstants.COLOR_F8F8FF),

	/**
	 * UiGradient name "Nighthawk" -
	 * <span style="background: linear-gradient(to right, #2980b9, #2c3e50); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	NIGHTHAWK(UiGradientConstants.COLOR_2980B9, UiGradientConstants.COLOR_2C3E50),

	/**
	 * UiGradient name "Nimvelo" -
	 * <span style="background: linear-gradient(to right, #314755, #26a0da); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	NIMVELO(UiGradientConstants.COLOR_314755, UiGradientConstants.COLOR_26A0DA),

	/**
	 * UiGradient name "Noon to Dusk" -
	 * <span style="background: linear-gradient(to right, #ff6e7f, #bfe9ff); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	NOON_TO_DUSK(UiGradientConstants.COLOR_FF6E7F, UiGradientConstants.COLOR_BFE9FF),

	/**
	 * UiGradient name "Ohhappiness" -
	 * <span style="background: linear-gradient(to right, #00b09b, #96c93d); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	OHHAPPINESS(UiGradientConstants.COLOR_00B09B, UiGradientConstants.COLOR_96C93D),

	/**
	 * UiGradient name "Omolon" -
	 * <span style="background: linear-gradient(to right, #091E3A, #2F80ED, #2D9EE0); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	OMOLON(UiGradientConstants.COLOR_091E3A, UiGradientConstants.COLOR_2F80ED, UiGradientConstants.COLOR_2D9EE0),

	/**
	 * UiGradient name "Opa" -
	 * <span style="background: linear-gradient(to right, #3D7EAA, #FFE47A); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	OPA(UiGradientConstants.COLOR_3D7EAA, UiGradientConstants.COLOR_FFE47A),

	/**
	 * UiGradient name "Orange Coral" -
	 * <span style="background: linear-gradient(to right, #ff9966, #ff5e62); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ORANGE_CORAL(UiGradientConstants.COLOR_FF9966, UiGradientConstants.COLOR_FF5E62),

	/**
	 * UiGradient name "Orange Fun" -
	 * <span style="background: linear-gradient(to right, #fc4a1a, #f7b733); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ORANGE_FUN(UiGradientConstants.COLOR_FC4A1A, UiGradientConstants.COLOR_F7B733),

	/**
	 * UiGradient name "Orca" -
	 * <span style="background: linear-gradient(to right, #44A08D, #093637); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ORCA(UiGradientConstants.COLOR_44A08D, UiGradientConstants.COLOR_093637),

	/**
	 * UiGradient name "Pacific Dream" -
	 * <span style="background: linear-gradient(to right, #34e89e, #0f3443); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PACIFIC_DREAM(UiGradientConstants.COLOR_34E89E, UiGradientConstants.COLOR_0F3443),

	/**
	 * UiGradient name "Pale Wood" -
	 * <span style="background: linear-gradient(to right, #eacda3, #d6ae7b); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PALE_WOOD(UiGradientConstants.COLOR_EACDA3, UiGradientConstants.COLOR_D6AE7B),

	/**
	 * UiGradient name "Parklife" -
	 * <span style="background: linear-gradient(to right, #ADD100, #7B920A); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PARKLIFE(UiGradientConstants.COLOR_ADD100, UiGradientConstants.COLOR_7B920A),

	/**
	 * UiGradient name "Passion" -
	 * <span style="background: linear-gradient(to right, #e53935, #e35d5b); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PASSION(UiGradientConstants.COLOR_E53935, UiGradientConstants.COLOR_E35D5B),

	/**
	 * UiGradient name "Pastel Orange at the Sun" -
	 * <span style="background: linear-gradient(to right, #ffb347, #ffcc33); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PASTEL_ORANGE_AT_THE_SUN(UiGradientConstants.COLOR_FFB347, UiGradientConstants.COLOR_FFCC33),

	/**
	 * UiGradient name "Peach" -
	 * <span style="background: linear-gradient(to right, #ED4264, #FFEDBC); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PEACH(UiGradientConstants.COLOR_ED4264, UiGradientConstants.COLOR_FFEDBC),

	/**
	 * UiGradient name "Peach Sea" -
	 * <span style="background: linear-gradient(to right, #E6AE8C, #A8CECF); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PEACH_SEA(UiGradientConstants.COLOR_E6AE8C, UiGradientConstants.COLOR_A8CECF),

	/**
	 * UiGradient name "Petrichor" -
	 * <span style="background: linear-gradient(to right, #666600, #999966); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PETRICHOR(UiGradientConstants.COLOR_666600, UiGradientConstants.COLOR_999966),

	/**
	 * UiGradient name "Petrol" -
	 * <span style="background: linear-gradient(to right, #BBD2C5, #536976); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PETROL(UiGradientConstants.COLOR_BBD2C5, UiGradientConstants.COLOR_536976),

	/**
	 * UiGradient name "Piggy Pink" -
	 * <span style="background: linear-gradient(to right, #ee9ca7, #ffdde1); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PIGGY_PINK(UiGradientConstants.COLOR_EE9CA7, UiGradientConstants.COLOR_FFDDE1),

	/**
	 * UiGradient name "Piglet" -
	 * <span style="background: linear-gradient(to right, #ee9ca7, #ffdde1); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PIGLET(UiGradientConstants.COLOR_EE9CA7, UiGradientConstants.COLOR_FFDDE1),

	/**
	 * UiGradient name "Pink Flavour" -
	 * <span style="background: linear-gradient(to right, #800080, #ffc0cb); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PINK_FLAVOUR(UiGradientConstants.COLOR_800080, UiGradientConstants.COLOR_FFC0CB),

	/**
	 * UiGradient name "Pinky" -
	 * <span style="background: linear-gradient(to right, #DD5E89, #F7BB97); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PINKY(UiGradientConstants.COLOR_DD5E89, UiGradientConstants.COLOR_F7BB97),

	/**
	 * UiGradient name "Pinot Noir" -
	 * <span style="background: linear-gradient(to right, #4b6cb7, #182848); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PINOT_NOIR(UiGradientConstants.COLOR_4B6CB7, UiGradientConstants.COLOR_182848),

	/**
	 * UiGradient name "Pizelex" -
	 * <span style="background: linear-gradient(to right, #114357, #F29492); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PIZELEX(UiGradientConstants.COLOR_114357, UiGradientConstants.COLOR_F29492),

	/**
	 * UiGradient name "Playing with Reds" -
	 * <span style="background: linear-gradient(to right, #D31027, #EA384D); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PLAYING_WITH_REDS(UiGradientConstants.COLOR_D31027, UiGradientConstants.COLOR_EA384D),

	/**
	 * UiGradient name "Politics" -
	 * <span style="background: linear-gradient(to right, #2196f3, #f44336); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	POLITICS(UiGradientConstants.COLOR_2196F3, UiGradientConstants.COLOR_F44336),

	/**
	 * UiGradient name "Poncho" -
	 * <span style="background: linear-gradient(to right, #403A3E, #BE5869); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PONCHO(UiGradientConstants.COLOR_403A3E, UiGradientConstants.COLOR_BE5869),

	/**
	 * UiGradient name "Portrait" -
	 * <span style="background: linear-gradient(to right, #8e9eab, #eef2f3); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PORTRAIT(UiGradientConstants.COLOR_8E9EAB, UiGradientConstants.COLOR_EEF2F3),

	/**
	 * UiGradient name "Predawn" -
	 * <span style="background: linear-gradient(to right, #FFA17F, #00223E); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PREDAWN(UiGradientConstants.COLOR_FFA17F, UiGradientConstants.COLOR_00223E),

	/**
	 * UiGradient name "Pun Yeta" -
	 * <span style="background: linear-gradient(to right, #108dc7, #ef8e38); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PUN_YETA(UiGradientConstants.COLOR_108DC7, UiGradientConstants.COLOR_EF8E38),

	/**
	 * UiGradient name "Pure Lust" -
	 * <span style="background: linear-gradient(to right, #333333, #dd1818); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PURE_LUST(UiGradientConstants.COLOR_333333, UiGradientConstants.COLOR_DD1818),

	/**
	 * UiGradient name "Purpink" -
	 * <span style="background: linear-gradient(to right, #7F00FF, #E100FF); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PURPINK(UiGradientConstants.COLOR_7F00FF, UiGradientConstants.COLOR_E100FF),

	/**
	 * UiGradient name "Purple" -
	 * <span style="background: linear-gradient(to right, #c84e89, #F15F79); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PURPLE(UiGradientConstants.COLOR_C84E89, UiGradientConstants.COLOR_F15F79),

	/**
	 * UiGradient name "Purple Bliss" -
	 * <span style="background: linear-gradient(to right, #360033, #0b8793); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PURPLE_BLISS(UiGradientConstants.COLOR_360033, UiGradientConstants.COLOR_0B8793),

	/**
	 * UiGradient name "Purple Dream" -
	 * <span style="background: linear-gradient(to right, #bf5ae0, #a811da); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PURPLE_DREAM(UiGradientConstants.COLOR_BF5AE0, UiGradientConstants.COLOR_A811DA),

	/**
	 * UiGradient name "Purple Love" -
	 * <span style="background: linear-gradient(to right, #cc2b5e, #753a88); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PURPLE_LOVE(UiGradientConstants.COLOR_CC2B5E, UiGradientConstants.COLOR_753A88),

	/**
	 * UiGradient name "Purple Paradise" -
	 * <span style="background: linear-gradient(to right, #1D2B64, #F8CDDA); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PURPLE_PARADISE(UiGradientConstants.COLOR_1D2B64, UiGradientConstants.COLOR_F8CDDA),

	/**
	 * UiGradient name "Purple White" -
	 * <span style="background: linear-gradient(to right, #BA5370, #F4E2D8); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PURPLE_WHITE(UiGradientConstants.COLOR_BA5370, UiGradientConstants.COLOR_F4E2D8),

	/**
	 * UiGradient name "Purplepine" -
	 * <span style="background: linear-gradient(to right, #20002c, #cbb4d4); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PURPLEPINE(UiGradientConstants.COLOR_20002C, UiGradientConstants.COLOR_CBB4D4),

	/**
	 * UiGradient name "Purplin" -
	 * <span style="background: linear-gradient(to right, #6a3093, #a044ff); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	PURPLIN(UiGradientConstants.COLOR_6A3093, UiGradientConstants.COLOR_A044FF),

	/**
	 * UiGradient name "Quepal" -
	 * <span style="background: linear-gradient(to right, #11998e, #38ef7d); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	QUEPAL(UiGradientConstants.COLOR_11998E, UiGradientConstants.COLOR_38EF7D),

	/**
	 * UiGradient name "Racker" -
	 * <span style="background: linear-gradient(to right, #EB0000, #95008A, #3300FC); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	RACKER(UiGradientConstants.COLOR_EB0000, UiGradientConstants.COLOR_95008A, UiGradientConstants.COLOR_3300FC),

	/**
	 * UiGradient name "Radar" -
	 * <span style="background: linear-gradient(to right, #A770EF, #CF8BF3, #FDB99B); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	RADAR(UiGradientConstants.COLOR_A770EF, UiGradientConstants.COLOR_CF8BF3, UiGradientConstants.COLOR_FDB99B),

	/**
	 * UiGradient name "Radioactive Heat" -
	 * <span style="background: linear-gradient(to right, #F7941E, #72C6EF, #00A651); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	RADIOACTIVE_HEAT(UiGradientConstants.COLOR_F7941E, UiGradientConstants.COLOR_72C6EF, UiGradientConstants.COLOR_00A651),

	/**
	 * UiGradient name "Rainbow Blue" -
	 * <span style="background: linear-gradient(to right, #00F260, #0575E6); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	RAINBOW_BLUE(UiGradientConstants.COLOR_00F260, UiGradientConstants.COLOR_0575E6),

	/**
	 * UiGradient name "Rastafari" -
	 * <span style="background: linear-gradient(to right, #1E9600, #FFF200, #FF0000); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	RASTAFARI(UiGradientConstants.COLOR_1E9600, UiGradientConstants.COLOR_FFF200, UiGradientConstants.COLOR_FF0000),

	/**
	 * UiGradient name "Rea" -
	 * <span style="background: linear-gradient(to right, #FFE000, #799F0C); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	REA(UiGradientConstants.COLOR_FFE000, UiGradientConstants.COLOR_799F0C),

	/**
	 * UiGradient name "Reaqua" -
	 * <span style="background: linear-gradient(to right, #799F0C, #ACBB78); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	REAQUA(UiGradientConstants.COLOR_799F0C, UiGradientConstants.COLOR_ACBB78),

	/**
	 * UiGradient name "Red Mist" -
	 * <span style="background: linear-gradient(to right, #000000, #e74c3c); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	RED_MIST(UiGradientConstants.COLOR_000000, UiGradientConstants.COLOR_E74C3C),

	/**
	 * UiGradient name "Red Ocean" -
	 * <span style="background: linear-gradient(to right, #1D4350, #A43931); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	RED_OCEAN(UiGradientConstants.COLOR_1D4350, UiGradientConstants.COLOR_A43931),

	/**
	 * UiGradient name "Red Sunset" -
	 * <span style="background: linear-gradient(to right, #355C7D, #6C5B7B, #C06C84); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	RED_SUNSET(UiGradientConstants.COLOR_355C7D, UiGradientConstants.COLOR_6C5B7B, UiGradientConstants.COLOR_C06C84),

	/**
	 * UiGradient name "Reef" -
	 * <span style="background: linear-gradient(to right, #00d2ff, #3a7bd5); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	REEF(UiGradientConstants.COLOR_00D2FF, UiGradientConstants.COLOR_3A7BD5),

	/**
	 * UiGradient name "Relaxing red" -
	 * <span style="background: linear-gradient(to right, #fffbd5, #b20a2c); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	RELAXING_RED(UiGradientConstants.COLOR_FFFBD5, UiGradientConstants.COLOR_B20A2C),

	/**
	 * UiGradient name "Relay" -
	 * <span style="background: linear-gradient(to right, #3A1C71, #D76D77, #FFAF7B); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	RELAY(UiGradientConstants.COLOR_3A1C71, UiGradientConstants.COLOR_D76D77, UiGradientConstants.COLOR_FFAF7B),

	/**
	 * UiGradient name "Rose Colored Lenses" -
	 * <span style="background: linear-gradient(to right, #E8CBC0, #636FA4); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ROSE_COLORED_LENSES(UiGradientConstants.COLOR_E8CBC0, UiGradientConstants.COLOR_636FA4),

	/**
	 * UiGradient name "Rose Water" -
	 * <span style="background: linear-gradient(to right, #E55D87, #5FC3E4); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ROSE_WATER(UiGradientConstants.COLOR_E55D87, UiGradientConstants.COLOR_5FC3E4),

	/**
	 * UiGradient name "Roseanna" -
	 * <span style="background: linear-gradient(to right, #FFAFBD, #ffc3a0); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ROSEANNA(UiGradientConstants.COLOR_FFAFBD, UiGradientConstants.COLOR_FFC3A0),

	/**
	 * UiGradient name "Royal" -
	 * <span style="background: linear-gradient(to right, #141E30, #243B55); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ROYAL(UiGradientConstants.COLOR_141E30, UiGradientConstants.COLOR_243B55),

	/**
	 * UiGradient name "Royal Blue" -
	 * <span style="background: linear-gradient(to right, #536976, #292E49); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ROYAL_BLUE(UiGradientConstants.COLOR_536976, UiGradientConstants.COLOR_292E49),

	/**
	 * UiGradient name "Royal Blue + Petrol" -
	 * <span style="background: linear-gradient(to right, #BBD2C5, #536976, #292E49); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ROYAL_BLUE_PLUS_PETROL(UiGradientConstants.COLOR_BBD2C5, UiGradientConstants.COLOR_536976, UiGradientConstants.COLOR_292E49),

	/**
	 * UiGradient name "Sage Persuasion" -
	 * <span style="background: linear-gradient(to right, #CCCCB2, #757519); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SAGE_PERSUASION(UiGradientConstants.COLOR_CCCCB2, UiGradientConstants.COLOR_757519),

	/**
	 * UiGradient name "Sand to Blue" -
	 * <span style="background: linear-gradient(to right, #3E5151, #DECBA4); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SAND_TO_BLUE(UiGradientConstants.COLOR_3E5151, UiGradientConstants.COLOR_DECBA4),

	/**
	 * UiGradient name "Scooter" -
	 * <span style="background: linear-gradient(to right, #36D1DC, #5B86E5); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SCOOTER(UiGradientConstants.COLOR_36D1DC, UiGradientConstants.COLOR_5B86E5),

	/**
	 * UiGradient name "Sea Blizz" -
	 * <span style="background: linear-gradient(to right, #1CD8D2, #93EDC7); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SEA_BLIZZ(UiGradientConstants.COLOR_1CD8D2, UiGradientConstants.COLOR_93EDC7),

	/**
	 * UiGradient name "Sea Blue" -
	 * <span style="background: linear-gradient(to right, #2b5876, #4e4376); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SEA_BLUE(UiGradientConstants.COLOR_2B5876, UiGradientConstants.COLOR_4E4376),

	/**
	 * UiGradient name "Sea Weed" -
	 * <span style="background: linear-gradient(to right, #4CB8C4, #3CD3AD); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SEA_WEED(UiGradientConstants.COLOR_4CB8C4, UiGradientConstants.COLOR_3CD3AD),

	/**
	 * UiGradient name "Sel" -
	 * <span style="background: linear-gradient(to right, #00467F, #A5CC82); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SEL(UiGradientConstants.COLOR_00467F, UiGradientConstants.COLOR_A5CC82),

	/**
	 * UiGradient name "Selenium" -
	 * <span style="background: linear-gradient(to right, #3C3B3F, #605C3C); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SELENIUM(UiGradientConstants.COLOR_3C3B3F, UiGradientConstants.COLOR_605C3C),

	/**
	 * UiGradient name "ServQuick" -
	 * <span style="background: linear-gradient(to right, #485563, #29323c); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SERVQUICK(UiGradientConstants.COLOR_485563, UiGradientConstants.COLOR_29323C),

	/**
	 * UiGradient name "Sexy Blue" -
	 * <span style="background: linear-gradient(to right, #2193b0, #6dd5ed); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SEXY_BLUE(UiGradientConstants.COLOR_2193B0, UiGradientConstants.COLOR_6DD5ED),

	/**
	 * UiGradient name "Sha la la" -
	 * <span style="background: linear-gradient(to right, #D66D75, #E29587); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SHA_LA_LA(UiGradientConstants.COLOR_D66D75, UiGradientConstants.COLOR_E29587),

	/**
	 * UiGradient name "Shahabi" -
	 * <span style="background: linear-gradient(to right, #a80077, #66ff00); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SHAHABI(UiGradientConstants.COLOR_A80077, UiGradientConstants.COLOR_66FF00),

	/**
	 * UiGradient name "Sherbert" -
	 * <span style="background: linear-gradient(to right, #f79d00, #64f38c); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SHERBERT(UiGradientConstants.COLOR_F79D00, UiGradientConstants.COLOR_64F38C),

	/**
	 * UiGradient name "Shifter" -
	 * <span style="background: linear-gradient(to right, #bc4e9c, #f80759); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SHIFTER(UiGradientConstants.COLOR_BC4E9C, UiGradientConstants.COLOR_F80759),

	/**
	 * UiGradient name "Shifty" -
	 * <span style="background: linear-gradient(to right, #636363, #a2ab58); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SHIFTY(UiGradientConstants.COLOR_636363, UiGradientConstants.COLOR_A2AB58),

	/**
	 * UiGradient name "Shore" -
	 * <span style="background: linear-gradient(to right, #70e1f5, #ffd194); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SHORE(UiGradientConstants.COLOR_70E1F5, UiGradientConstants.COLOR_FFD194),

	/**
	 * UiGradient name "Shrimpy" -
	 * <span style="background: linear-gradient(to right, #e43a15, #e65245); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SHRIMPY(UiGradientConstants.COLOR_E43A15, UiGradientConstants.COLOR_E65245),

	/**
	 * UiGradient name "Shroom Haze" -
	 * <span style="background: linear-gradient(to right, #5C258D, #4389A2); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SHROOM_HAZE(UiGradientConstants.COLOR_5C258D, UiGradientConstants.COLOR_4389A2),

	/**
	 * UiGradient name "Sin City Red" -
	 * <span style="background: linear-gradient(to right, #ED213A, #93291E); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SIN_CITY_RED(UiGradientConstants.COLOR_ED213A, UiGradientConstants.COLOR_93291E),

	/**
	 * UiGradient name "Sirius Tamed" -
	 * <span style="background: linear-gradient(to right, #EFEFBB, #D4D3DD); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SIRIUS_TAMED(UiGradientConstants.COLOR_EFEFBB, UiGradientConstants.COLOR_D4D3DD),

	/**
	 * UiGradient name "Sky" -
	 * <span style="background: linear-gradient(to right, #076585, #fff); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SKY(UiGradientConstants.COLOR_076585, UiGradientConstants.COLOR_FFF),

	/**
	 * UiGradient name "Skyline" -
	 * <span style="background: linear-gradient(to right, #1488CC, #2B32B2); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SKYLINE(UiGradientConstants.COLOR_1488CC, UiGradientConstants.COLOR_2B32B2),

	/**
	 * UiGradient name "Slight Ocean View" -
	 * <span style="background: linear-gradient(to right, #a8c0ff, #3f2b96); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SLIGHT_OCEAN_VIEW(UiGradientConstants.COLOR_A8C0FF, UiGradientConstants.COLOR_3F2B96),

	/**
	 * UiGradient name "Snapchat" -
	 * <span style="background: linear-gradient(to right, #fffc00, #ffffff); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SNAPCHAT(UiGradientConstants.COLOR_FFFC00, UiGradientConstants.COLOR_FFFFFF),

	/**
	 * UiGradient name "Socialive" -
	 * <span style="background: linear-gradient(to right, #06beb6, #48b1bf); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SOCIALIVE(UiGradientConstants.COLOR_06BEB6, UiGradientConstants.COLOR_48B1BF),

	/**
	 * UiGradient name "Solid Vault" -
	 * <span style="background: linear-gradient(to right, #3a7bd5, #3a6073); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SOLID_VAULT(UiGradientConstants.COLOR_3A7BD5, UiGradientConstants.COLOR_3A6073),

	/**
	 * UiGradient name "SoundCloud" -
	 * <span style="background: linear-gradient(to right, #fe8c00, #f83600); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SOUNDCLOUD(UiGradientConstants.COLOR_FE8C00, UiGradientConstants.COLOR_F83600),

	/**
	 * UiGradient name "Space Light Green" -
	 * <span style="background: linear-gradient(to right, #9FA0A8, #5C7852); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SPACE_LIGHT_GREEN(UiGradientConstants.COLOR_9FA0A8, UiGradientConstants.COLOR_5C7852),

	/**
	 * UiGradient name "Starfall" -
	 * <span style="background: linear-gradient(to right, #F0C27B, #4B1248); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	STARFALL(UiGradientConstants.COLOR_F0C27B, UiGradientConstants.COLOR_4B1248),

	/**
	 * UiGradient name "Steel Gray" -
	 * <span style="background: linear-gradient(to right, #1F1C2C, #928DAB); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	STEEL_GRAY(UiGradientConstants.COLOR_1F1C2C, UiGradientConstants.COLOR_928DAB),

	/**
	 * UiGradient name "Stellar" -
	 * <span style="background: linear-gradient(to right, #7474BF, #348AC7); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	STELLAR(UiGradientConstants.COLOR_7474BF, UiGradientConstants.COLOR_348AC7),

	/**
	 * UiGradient name "Stripe" -
	 * <span style="background: linear-gradient(to right, #1FA2FF, #12D8FA, #A6FFCB); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	STRIPE(UiGradientConstants.COLOR_1FA2FF, UiGradientConstants.COLOR_12D8FA, UiGradientConstants.COLOR_A6FFCB),

	/**
	 * UiGradient name "Sublime Light" -
	 * <span style="background: linear-gradient(to right, #FC5C7D, #6A82FB); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SUBLIME_LIGHT(UiGradientConstants.COLOR_FC5C7D, UiGradientConstants.COLOR_6A82FB),

	/**
	 * UiGradient name "Sublime Vivid" -
	 * <span style="background: linear-gradient(to right, #FC466B, #3F5EFB); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SUBLIME_VIVID(UiGradientConstants.COLOR_FC466B, UiGradientConstants.COLOR_3F5EFB),

	/**
	 * UiGradient name "Subu" -
	 * <span style="background: linear-gradient(to right, #0cebeb, #20e3b2, #29ffc6); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SUBU(UiGradientConstants.COLOR_0CEBEB, UiGradientConstants.COLOR_20E3B2, UiGradientConstants.COLOR_29FFC6),

	/**
	 * UiGradient name "Sulphur" -
	 * <span style="background: linear-gradient(to right, #CAC531, #F3F9A7); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SULPHUR(UiGradientConstants.COLOR_CAC531, UiGradientConstants.COLOR_F3F9A7),

	/**
	 * UiGradient name "Summer" -
	 * <span style="background: linear-gradient(to right, #22c1c3, #fdbb2d); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SUMMER(UiGradientConstants.COLOR_22C1C3, UiGradientConstants.COLOR_FDBB2D),

	/**
	 * UiGradient name "Summer Breeze" -
	 * <span style="background: linear-gradient(to right, #fbed96, #abecd6); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SUMMER_BREEZE(UiGradientConstants.COLOR_FBED96, UiGradientConstants.COLOR_ABECD6),

	/**
	 * UiGradient name "Summer Dog" -
	 * <span style="background: linear-gradient(to right, #a8ff78, #78ffd6); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SUMMER_DOG(UiGradientConstants.COLOR_A8FF78, UiGradientConstants.COLOR_78FFD6),

	/**
	 * UiGradient name "Sun on the Horizon" -
	 * <span style="background: linear-gradient(to right, #fceabb, #f8b500); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SUN_ON_THE_HORIZON(UiGradientConstants.COLOR_FCEABB, UiGradientConstants.COLOR_F8B500),

	/**
	 * UiGradient name "Sunkist" -
	 * <span style="background: linear-gradient(to right, #F2994A, #F2C94C); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SUNKIST(UiGradientConstants.COLOR_F2994A, UiGradientConstants.COLOR_F2C94C),

	/**
	 * UiGradient name "Sunny Days" -
	 * <span style="background: linear-gradient(to right, #EDE574, #E1F5C4); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SUNNY_DAYS(UiGradientConstants.COLOR_EDE574, UiGradientConstants.COLOR_E1F5C4),

	/**
	 * UiGradient name "Sunrise" -
	 * <span style="background: linear-gradient(to right, #FF512F, #F09819); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SUNRISE(UiGradientConstants.COLOR_FF512F, UiGradientConstants.COLOR_F09819),

	/**
	 * UiGradient name "Sunset" -
	 * <span style="background: linear-gradient(to right, #0B486B, #F56217); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SUNSET(UiGradientConstants.COLOR_0B486B, UiGradientConstants.COLOR_F56217),

	/**
	 * UiGradient name "Superman" -
	 * <span style="background: linear-gradient(to right, #0099F7, #F11712); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SUPERMAN(UiGradientConstants.COLOR_0099F7, UiGradientConstants.COLOR_F11712),

	/**
	 * UiGradient name "Suzy" -
	 * <span style="background: linear-gradient(to right, #834d9b, #d04ed6); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SUZY(UiGradientConstants.COLOR_834D9B, UiGradientConstants.COLOR_D04ED6),

	/**
	 * UiGradient name "Sweet Morning" -
	 * <span style="background: linear-gradient(to right, #FF5F6D, #FFC371); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SWEET_MORNING(UiGradientConstants.COLOR_FF5F6D, UiGradientConstants.COLOR_FFC371),

	/**
	 * UiGradient name "Sylvia" -
	 * <span style="background: linear-gradient(to right, #ff4b1f, #ff9068); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	SYLVIA(UiGradientConstants.COLOR_FF4B1F, UiGradientConstants.COLOR_FF9068),

	/**
	 * UiGradient name "Talking To Mice Elf" -
	 * <span style="background: linear-gradient(to right, #948E99, #2E1437); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TALKING_TO_MICE_ELF(UiGradientConstants.COLOR_948E99, UiGradientConstants.COLOR_2E1437),

	/**
	 * UiGradient name "Taran Tado" -
	 * <span style="background: linear-gradient(to right, #23074d, #cc5333); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TARAN_TADO(UiGradientConstants.COLOR_23074D, UiGradientConstants.COLOR_CC5333),

	/**
	 * UiGradient name "Teal Love" -
	 * <span style="background: linear-gradient(to right, #AAFFA9, #11FFBD); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TEAL_LOVE(UiGradientConstants.COLOR_AAFFA9, UiGradientConstants.COLOR_11FFBD),

	/**
	 * UiGradient name "Telegram" -
	 * <span style="background: linear-gradient(to right, #1c92d2, #f2fcfe); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TELEGRAM(UiGradientConstants.COLOR_1C92D2, UiGradientConstants.COLOR_F2FCFE),

	/**
	 * UiGradient name "Telko" -
	 * <span style="background: linear-gradient(to right, #F36222, #5CB644, #007FC3); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TELKO(UiGradientConstants.COLOR_F36222, UiGradientConstants.COLOR_5CB644, UiGradientConstants.COLOR_007FC3),

	/**
	 * UiGradient name "Terminal" -
	 * <span style="background: linear-gradient(to right, #000000, #0f9b0f); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TERMINAL(UiGradientConstants.COLOR_000000, UiGradientConstants.COLOR_0F9B0F),

	/**
	 * UiGradient name "The Blue Lagoon" -
	 * <span style="background: linear-gradient(to right, #43C6AC, #191654); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	THE_BLUE_LAGOON(UiGradientConstants.COLOR_43C6AC, UiGradientConstants.COLOR_191654),

	/**
	 * UiGradient name "The Sky And The Sea" -
	 * <span style="background: linear-gradient(to right, #F7941E, #004E8F); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	THE_SKY_AND_THE_SEA(UiGradientConstants.COLOR_F7941E, UiGradientConstants.COLOR_004E8F),

	/**
	 * UiGradient name "The Strain" -
	 * <span style="background: linear-gradient(to right, #870000, #190A05); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	THE_STRAIN(UiGradientConstants.COLOR_870000, UiGradientConstants.COLOR_190A05),

	/**
	 * UiGradient name "Timber" -
	 * <span style="background: linear-gradient(to right, #fc00ff, #00dbde); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TIMBER(UiGradientConstants.COLOR_FC00FF, UiGradientConstants.COLOR_00DBDE),

	/**
	 * UiGradient name "Titanium" -
	 * <span style="background: linear-gradient(to right, #283048, #859398); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TITANIUM(UiGradientConstants.COLOR_283048, UiGradientConstants.COLOR_859398),

	/**
	 * UiGradient name "Tranquil" -
	 * <span style="background: linear-gradient(to right, #EECDA3, #EF629F); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TRANQUIL(UiGradientConstants.COLOR_EECDA3, UiGradientConstants.COLOR_EF629F),

	/**
	 * UiGradient name "Transfile" -
	 * <span style="background: linear-gradient(to right, #16BFFD, #CB3066); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TRANSFILE(UiGradientConstants.COLOR_16BFFD, UiGradientConstants.COLOR_CB3066),

	/**
	 * UiGradient name "Turquoise flow" -
	 * <span style="background: linear-gradient(to right, #136a8a, #267871); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TURQUOISE_FLOW(UiGradientConstants.COLOR_136A8A, UiGradientConstants.COLOR_267871),

	/**
	 * UiGradient name "Twitch" -
	 * <span style="background: linear-gradient(to right, #6441A5, #2a0845); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TWITCH(UiGradientConstants.COLOR_6441A5, UiGradientConstants.COLOR_2A0845),

	/**
	 * UiGradient name "Twitter" -
	 * <span style="background: linear-gradient(to right, #1DA1F2, #009ffc); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	TWITTER(UiGradientConstants.COLOR_1DA1F2, UiGradientConstants.COLOR_009FFC),

	/**
	 * UiGradient name "Ukraine" -
	 * <span style="background: linear-gradient(to right, #004FF9, #FFF94C); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	UKRAINE(UiGradientConstants.COLOR_004FF9, UiGradientConstants.COLOR_FFF94C),

	/**
	 * UiGradient name "Ultra Voilet" -
	 * <span style="background: linear-gradient(to right, #654ea3, #eaafc8); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ULTRA_VOILET(UiGradientConstants.COLOR_654EA3, UiGradientConstants.COLOR_EAAFC8),

	/**
	 * UiGradient name "Under Blue Green" -
	 * <span style="background: linear-gradient(to right, #051937, #004d7a, #008793, #00bf72, #a8eb12); border-style: solid;
	 * border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	UNDER_BLUE_GREEN(UiGradientConstants.COLOR_051937, UiGradientConstants.COLOR_004D7A, UiGradientConstants.COLOR_008793, UiGradientConstants.COLOR_00BF72, UiGradientConstants.COLOR_A8EB12),

	/**
	 * UiGradient name "Under the Lake" -
	 * <span style="background: linear-gradient(to right, #093028, #237A57); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	UNDER_THE_LAKE(UiGradientConstants.COLOR_093028, UiGradientConstants.COLOR_237A57),

	/**
	 * UiGradient name "Unicorn Rainbow" -
	 * <span style="background: linear-gradient(to right, #f7f0ac, #acf7f0, #f0acf7); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	UNICORN_RAINBOW(UiGradientConstants.COLOR_F7F0AC, UiGradientConstants.COLOR_ACF7F0, UiGradientConstants.COLOR_F0ACF7),

	/**
	 * UiGradient name "Vanusa" -
	 * <span style="background: linear-gradient(to right, #DA4453, #89216B); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	VANUSA(UiGradientConstants.COLOR_DA4453, UiGradientConstants.COLOR_89216B),

	/**
	 * UiGradient name "Vasily" -
	 * <span style="background: linear-gradient(to right, #e9d362, #333333); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	VASILY(UiGradientConstants.COLOR_E9D362, UiGradientConstants.COLOR_333333),

	/**
	 * UiGradient name "Velvet Sun" -
	 * <span style="background: linear-gradient(to right, #e1eec3, #f05053); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	VELVET_SUN(UiGradientConstants.COLOR_E1EEC3, UiGradientConstants.COLOR_F05053),

	/**
	 * UiGradient name "Venice" -
	 * <span style="background: linear-gradient(to right, #6190E8, #A7BFE8); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	VENICE(UiGradientConstants.COLOR_6190E8, UiGradientConstants.COLOR_A7BFE8),

	/**
	 * UiGradient name "Venice Blue" -
	 * <span style="background: linear-gradient(to right, #085078, #85D8CE); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	VENICE_BLUE(UiGradientConstants.COLOR_085078, UiGradientConstants.COLOR_85D8CE),

	/**
	 * UiGradient name "Ver" -
	 * <span style="background: linear-gradient(to right, #FFE000, #799F0C); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	VER(UiGradientConstants.COLOR_FFE000, UiGradientConstants.COLOR_799F0C),

	/**
	 * UiGradient name "Ver Black" -
	 * <span style="background: linear-gradient(to right, #F7F8F8, #ACBB78); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	VER_BLACK(UiGradientConstants.COLOR_F7F8F8, UiGradientConstants.COLOR_ACBB78),

	/**
	 * UiGradient name "Very Blue" -
	 * <span style="background: linear-gradient(to right, #0575E6, #021B79); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	VERY_BLUE(UiGradientConstants.COLOR_0575E6, UiGradientConstants.COLOR_021B79),

	/**
	 * UiGradient name "Vice City" -
	 * <span style="background: linear-gradient(to right, #3494E6, #EC6EAD); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	VICE_CITY(UiGradientConstants.COLOR_3494E6, UiGradientConstants.COLOR_EC6EAD),

	/**
	 * UiGradient name "Vine" -
	 * <span style="background: linear-gradient(to right, #00bf8f, #001510); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	VINE(UiGradientConstants.COLOR_00BF8F, UiGradientConstants.COLOR_001510),

	/**
	 * UiGradient name "Virgin" -
	 * <span style="background: linear-gradient(to right, #C9FFBF, #FFAFBD); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	VIRGIN(UiGradientConstants.COLOR_C9FFBF, UiGradientConstants.COLOR_FFAFBD),

	/**
	 * UiGradient name "Virgin America" -
	 * <span style="background: linear-gradient(to right, #7b4397, #dc2430); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	VIRGIN_AMERICA(UiGradientConstants.COLOR_7B4397, UiGradientConstants.COLOR_DC2430),

	/**
	 * UiGradient name "Visions of Grandeur" -
	 * <span style="background: linear-gradient(to right, #000046, #1CB5E0); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	VISIONS_OF_GRANDEUR(UiGradientConstants.COLOR_000046, UiGradientConstants.COLOR_1CB5E0),

	/**
	 * UiGradient name "Visual Blue" -
	 * <span style="background: linear-gradient(to right, #003d4d, #00c996); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	VISUAL_BLUE(UiGradientConstants.COLOR_003D4D, UiGradientConstants.COLOR_00C996),

	/**
	 * UiGradient name "Wedding Day Blues" -
	 * <span style="background: linear-gradient(to right, #40E0D0, #FF8C00, #FF0080); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	WEDDING_DAY_BLUES(UiGradientConstants.COLOR_40E0D0, UiGradientConstants.COLOR_FF8C00, UiGradientConstants.COLOR_FF0080),

	/**
	 * UiGradient name "What lies Beyond" -
	 * <span style="background: linear-gradient(to right, #F0F2F0, #000C40); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	WHAT_LIES_BEYOND(UiGradientConstants.COLOR_F0F2F0, UiGradientConstants.COLOR_000C40),

	/**
	 * UiGradient name "Whinehouse" -
	 * <span style="background: linear-gradient(to right, #f7f7f7, #b9a0a0, #794747, #4e2020, #111111); border-style: solid;
	 * border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	WHINEHOUSE(UiGradientConstants.COLOR_F7F7F7, UiGradientConstants.COLOR_B9A0A0, UiGradientConstants.COLOR_794747, UiGradientConstants.COLOR_4E2020, UiGradientConstants.COLOR_111111),

	/**
	 * UiGradient name "Windy" -
	 * <span style="background: linear-gradient(to right, #acb6e5, #86fde8); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	WINDY(UiGradientConstants.COLOR_ACB6E5, UiGradientConstants.COLOR_86FDE8),

	/**
	 * UiGradient name "Winter" -
	 * <span style="background: linear-gradient(to right, #E6DADA, #274046); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	WINTER(UiGradientConstants.COLOR_E6DADA, UiGradientConstants.COLOR_274046),

	/**
	 * UiGradient name "Winter Woods" -
	 * <span style="background: linear-gradient(to right, #333333, #a2ab58, #A43931); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	WINTER_WOODS(UiGradientConstants.COLOR_333333, UiGradientConstants.COLOR_A2AB58, UiGradientConstants.COLOR_A43931),

	/**
	 * UiGradient name "Wiretap" -
	 * <span style="background: linear-gradient(to right, #8A2387, #E94057, #F27121); border-style: solid; border-width: 1px;
	 * font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	WIRETAP(UiGradientConstants.COLOR_8A2387, UiGradientConstants.COLOR_E94057, UiGradientConstants.COLOR_F27121),

	/**
	 * UiGradient name "Witching Hour" -
	 * <span style="background: linear-gradient(to right, #c31432, #240b36); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	WITCHING_HOUR(UiGradientConstants.COLOR_C31432, UiGradientConstants.COLOR_240B36),

	/**
	 * UiGradient name "Yoda" -
	 * <span style="background: linear-gradient(to right, #FF0099, #493240); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	YODA(UiGradientConstants.COLOR_FF0099, UiGradientConstants.COLOR_493240),

	/**
	 * UiGradient name "YouTube" -
	 * <span style="background: linear-gradient(to right, #e52d27, #b31217); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	YOUTUBE(UiGradientConstants.COLOR_E52D27, UiGradientConstants.COLOR_B31217),

	/**
	 * UiGradient name "Zenta" -
	 * <span style="background: linear-gradient(to right, #2A2D3E, #FECB6E); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ZENTA(UiGradientConstants.COLOR_2A2D3E, UiGradientConstants.COLOR_FECB6E),

	/**
	 * UiGradient name "Zinc" -
	 * <span style="background: linear-gradient(to right, #ADA996, #F2F2F2, #DBDBDB, #EAEAEA); border-style: solid;
	 * border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	ZINC(UiGradientConstants.COLOR_ADA996, UiGradientConstants.COLOR_F2F2F2, UiGradientConstants.COLOR_DBDBDB, UiGradientConstants.COLOR_EAEAEA),

	/**
	 * UiGradient name "eXpresso" -
	 * <span style="background: linear-gradient(to right, #ad5389, #3c1053); border-style: solid; border-width: 1px; font-size:
	 * 150%;">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
	 */
	EXPRESSO(UiGradientConstants.COLOR_AD5389, UiGradientConstants.COLOR_3C1053);

	private final String[] colors;

	/**
	 * Builds a gradient using argument as list of colors in HEX format.
	 * 
	 * @param hexColors list of colors in HEX format
	 */
	private UiGradient(String... hexColors) {
		colors = hexColors;
	}

	String[] getColors() {
		return colors;
	}

	/**
	 * Creates a LINEAR gradient, with <code>topDown</code> orientation and <code>chart</code> scope.
	 * 
	 * @return new gradient based on color of UiGradient list
	 */
	public Gradient createGradient() {
		return createGradient(GradientType.LINEAR);
	}

	/**
	 * Creates a gradient by a type, with <code>chart</code> scope.
	 * 
	 * @param type gradient type
	 * @return new gradient based on color of UiGradient list
	 */
	public Gradient createGradient(GradientType type) {
		return createGradient(type, GradientOrientation.getDefaultByType(type));
	}

	/**
	 * Creates a gradient by a type and an orientation, with <code>chart</code> scope.
	 * 
	 * @param type gradient type
	 * @param orientation orientation of gradient
	 * @return new gradient based on color of UiGradient list
	 */
	public Gradient createGradient(GradientType type, GradientOrientation orientation) {
		return createGradient(type, orientation, GradientScope.CHART);
	}

	/**
	 * Creates a gradient by a type and a scope.
	 * 
	 * @param type gradient type
	 * @param scope scope of gradient
	 * @return new gradient based on color of UiGradient list
	 */
	public Gradient createGradient(GradientType type, GradientScope scope) {
		return createGradient(type, GradientOrientation.getDefaultByType(type), scope);
	}

	/**
	 * Creates a gradient by a type, an orientation and a scope.
	 * 
	 * @param type gradient type
	 * @param orientation orientation of gradient
	 * @param scope scope of gradient
	 * @return new gradient based on color of UiGradient list
	 */
	public Gradient createGradient(GradientType type, GradientOrientation orientation, GradientScope scope) {
		// checks if array of colors preloaded is consistent
		if (colors == null || colors.length < 2) {
			// if not, exception
			throw new IllegalArgumentException("Colors list is not consistent. Must have 2 colors at least");
		}
		// creates a gradient
		Gradient gradient = new Gradient(type, orientation, scope);
		// sets the max length to use on after calculation
		// because the first and last colors have got
		// offset 0D and 1D.
		int maxLength = colors.length - 1;
		// adds the first color
		gradient.addColorStop(0D, colors[0]);
		// checks if there is more then 2 colors
		// becuase the first and last are added
		// out of cycle
		if (colors.length > 2) {
			// calculates the increment of offset
			// for gradient color
			double increment = 1D / maxLength;
			// initial value of offset
			double offset = 0D;
			// scans all colors between the 2nd and
			// the last (excluded)
			for (int i = 1; i < maxLength; i++) {
				// calculates the color offset
				offset += increment;
				// adds colors to gradient
				gradient.addColorStop(offset, colors[i]);
			}
		}
		// adds the last color
		gradient.addColorStop(1D, colors[maxLength]);
		return gradient;
	}

}
